<?php
if (!defined( 'ABSPATH'))
    exit;

if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    function trackfree_account_page()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            $trackfree_account_api_key = get_option('trackfree_account_api_key');
            $trackfree_account_verify = get_option('trackfree_account_verify');

            $appVerifyContent = '';

            if ($trackfree_account_api_key == '') {
                include ('getting-started.php');
            }
            if (($trackfree_account_api_key) && ($trackfree_account_verify == 0)) {
                $appVerifyContent = '<div class="trackfree-error-container">' . __('Your app is not verified. Click verify link and activate your app in your mail. Please refresh this page if you have already verified.', 'trackfree-woocommerce-tracking') . '</div>';
                include ('getting-started.php');
            }

            if (($trackfree_account_verify == 0) && ($trackfree_account_api_key)) {
                trackfree_verification_status();
            }

            if (($trackfree_account_api_key) && ($trackfree_account_verify)) {
                trackfree_account_page_action();
            }
        }
    }


    function trackfree_account_page_action()
    {
        $nonce = wp_create_nonce( 'TrackFree' );
        $trackfree_account_api_key = get_option('trackfree_account_api_key');

        $response = wp_remote_get(trackfree_url() . '/api/wc_plans?key=' . $trackfree_account_api_key,
            array(
                'sslverify' => false,
                'timeout' => 15
            )
        );

        $response_data = json_decode( wp_remote_retrieve_body( $response ), true );
        ?>
        <div class="notice notice-info notice-alt trackfree-message">
            <h3><?php _e('We appreciate your feedback!', 'trackfree-woocommerce-tracking'); ?></h3>
            <p><?php _e('Please take a moment to share your experience with TrackFree.', 'trackfree-woocommerce-tracking'); ?></p>
            <div class="trackfree-fd-ct">
                <div>
                    <span class="trackfree-tracking-icon icon-good"><a href="https://wordpress.org/support/plugin/trackfree-woocommerce-tracking/reviews/#new-post" target="_blank" style="text-decoration: none; font-size: 16px;"><?php _e('Good', 'trackfree-woocommerce-tracking'); ?></a></span>
                </div>
                <div style="margin-left: 16px;">
                    <span class="trackfree-tracking-icon icon-bad"><a href="https://trackfreehelp.freshdesk.com/support/tickets/new" target="_blank" style="text-decoration: none; font-size: 16px;"><?php _e('Bad', 'trackfree-woocommerce-tracking'); ?></a></span>
                </div>
            </div>
        </div>
        <div style="clear:both;"></div>
        <div class="wrap">
            <?php
            if ($response_data && $response_data['status'] == 'success') { ?>
                <div class="trackfree-wrap">
                    <div class="trackfree-ac-tl"><?php _e('Account', 'trackfree-woocommerce-tracking'); ?></div>
                    <div class="trackfree-flex">
                        <div class="left">
                            <h3><?php _e('Current plan info', 'trackfree-woocommerce-tracking');?></h3>
                        </div>
                        <div class="right">
                            <div class="trackfree-card">
                                <div>
                                    <div class="trackfree-pl-nm"><?php echo $response_data['data']['planName'];?></div>
                                    <div class="trackfree-us-dt" style="margin-top: 16px;">
                                        <div class="trackfree-ug-tl"><?php _e('Total', 'trackfree-woocommerce-tracking'); ?></div>
                                        <div class="trackfree-ug-rq"><span class="trackfree-ug-tl"><?php echo $response_data['data']['spend'];?></span><span class="trackfree-ug-sd">/<?php echo $response_data['data']['trackCount'];?> <?php _e('requests', 'trackfree-woocommerce-tracking'); ?></span></div>
                                    </div>
                                    <div id="trackfree-progressbar">
                                        <div style="width: <?php echo $response_data['data']['processed']; ?>%;"></div>
                                    </div>
                                </div>
                            </div>
                            <?php if ($response_data['data']['planName'] !== 'Free') { ?>
                                <div style="margin-top: 16px;">
                                    <a href="javascript:void(0)" id="show_more_plans"><?php _e('Show more plans', 'trackfree-woocommerce-tracking'); ?></a>
                                </div>
                            <?php } ?>
                        </div>
                    </div>

                    <div class="trackfree-flex" id="show_all_plans" style="margin-top: 24px; <?php if ($response_data['data']['planName'] !== 'Free') { ?>display: none;<?php } ?>">
                        <div class="left">
                            <h3><?php _e('Plan', 'trackfree-woocommerce-tracking');?></h3>
                        </div>
                        <div class="right">
                            <div class="trackfree-plan-card">
                                <div>
                                    <?php foreach ($response_data['data']['plans'] as $plan) {
                                        $currency = $plan['currency'];
                                        if ( $plan['currency'] == 'USD') {
                                            $currency = '$';
                                        } else if ( $plan['currency'] == 'INR') {
                                            $currency = '&#8377;';
                                        }
                                        ?>
                                        <div class="trackfree-pl-ls">
                                            <div class="trackfree-pl-ct" style="padding: 12px 16px;">
                                                <div>
                                                    <div class="trackfree-pl-tl">
                                                        <?php echo $plan['planName'];?> <?php echo $currency . $plan['planPrice'];?>/mo.
                                                    </div>
                                                    <div class="trackfree-pl-dc">
                                                        <?php echo $plan['planDescription'];?>
                                                    </div>
                                                </div>
                                                <div>
                                                    <?php if ($plan['isActivePlan'] == 0) { ?>
                                                        <a href="<?php echo trackfree_url();?>/wc_user_plans?key=<?php echo $trackfree_account_api_key;?>" target="_blank" class="button"><?php _e('Choose plan', 'trackfree-woocommerce-tracking');?></a>
                                                    <?php } else { ?>
                                                        <a href="javascript:void(0);" class="button button-primary"><?php _e('Current plan', 'trackfree-woocommerce-tracking');?></a>
                                                    <?php } ?>
                                                </div>
                                            </div>
                                        </div>
                                        <?php
                                    } ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
            } ?>
        </div>
        <?php
    }
}
?>
