<?php
if (!defined( 'ABSPATH'))
    exit;

if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    function trackfree_home_page()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            $trackfree_account_api_key = get_option('trackfree_account_api_key');
            $trackfree_account_verify = get_option('trackfree_account_verify');

            $appVerifyContent = '';

            if ($trackfree_account_api_key == '') {
                include ('getting-started.php');
            }
            if (($trackfree_account_api_key) && ($trackfree_account_verify == 0)) {
                $appVerifyContent = '<div class="trackfree-error-container">' . __('Your app is not verified. Click verify link and activate your app in your mail. Please refresh this page if you have already verified.', 'trackfree-woocommerce-tracking') . '</div>';
                include ('getting-started.php');
            }

            if (($trackfree_account_verify == 0) && ($trackfree_account_api_key)) {
                trackfree_verification_status();
            }

            if (($trackfree_account_api_key) && ($trackfree_account_verify)) {
                trackfree_home_page_action();
            }
        }
    }


    function trackfree_home_page_action()
    {
        $nonce = wp_create_nonce( 'TrackFree' );
        $trackfree_account_api_key = get_option('trackfree_account_api_key'); ?>
        <div class="wrap">
            <div class="trackfree-hm-wp">
                <h1 style="margin-left: 8px;"><?php echo __('Welcome to TrackFree', 'trackfree-woocommerce-tracking'); ?></h1>
                <div class="trackfree-row">
                    <div class="trackfree-col-5">
                        <div class="trackfree-card" id="track_page_section" style="margin-bottom: 16px; <?php if (get_option('trackfree_hide_track_page_info') == 1) { ?>display: none;<?php } ?>">
                            <a style="float: right;" href="javascript:void(0);" id="dismiss_track_page_info"><?php _e('Dismiss', 'trackfree-woocommerce-tracking'); ?></a>
                            <h2><?php echo __('Add tracking page to your storefront', 'trackfree-woocommerce-tracking'); ?></h2>
                            <p>
                                <?php echo sprintf(esc_html__('Your branded tracking page is ready, the URL is %1$s, add it to your store menus so your customers can track orders there.', 'trackfree-woocommerce-tracking'), '<a href="' . trackfree_track_page_url() . '" target="_blank">' . trackfree_track_page_url() . '</a>' ) ?>
                            </p>
                            <p>
                                <?php echo sprintf(esc_html__('Don’t know how to do this? Please follow %1$sthis instruction%2$s.', 'trackfree-woocommerce-tracking')
                                , '<a href="https://trackfreehelp.freshdesk.com/support/solutions/articles/65000181291" target="_blank">', '</a>') ?>
                            </p>
                            <div style="margin: 16px 0">
                                <button onclick="window.open('<?php  echo trackfree_track_page_url('', true)?>')" type="button" class="button button-primary"><?php echo __('Preview tracking page', 'trackfree-woocommerce-tracking'); ?></button>
                            </div>
                        </div>

                        <div class="trackfree-card">
                            <h2><?php echo __('Shipment performance', 'trackfree-woocommerce-tracking'); ?></h2>
                            <?php
                            $request = array(
                                'key' => $trackfree_account_api_key
                            );
                            $shipment_response = wp_remote_get(trackfree_url() . '/api/wc_shipment_details',
                            array(
                                'sslverify' => false,
                                'timeout' => 15,
                                'body' => $request
                            ));
                            $shipment_data = json_decode( wp_remote_retrieve_body( $shipment_response ), true );
                            if ($shipment_data['status'] == 'success') { ?>
                                <div>
                                    <?php if ($shipment_data['unknownTrack'] > 0) { ?>
                                        <div class="update-message notice inline notice-warning notice-alt">
                                            <p class="trackfree-un-dt"><?php _e('In-Progress Shipments', 'trackfree-woocommerce-tracking');?>: <b><?php echo $shipment_data['unknownTrack'];?></b>
                                                <a href="javascript:void(0);" style="text-decoration: none;" data-tf-modal-id="unknown-track-modal"><?php _e('See details', 'trackfree-woocommerce-tracking');?></a>
                                            </p>
                                        </div>
                                        <div id="unknown-track-modal" class="trackfree-modal-box" style="width: 520px;">
                                            <header>
                                                <a href="javascript:void(0);" class="trackfree-modal-close trackfree-close">X</a>
                                                <h3><?php _e('In-Progress Shipments', 'trackfree-woocommerce-tracking'); ?></h3>
                                            </header>
                                            <div class="modal-body">
                                                <p>
                                                    <?php _e('In-progress shipment indicates that carrier response is pending.', 'trackfree-woocommerce-tracking'); ?>
                                                </p>
                                                <p>
                                                    <?php _e('Reasons include: It takes a few hours for the tracking response to reflect, Invalid tracking code number, or Bulk mailing of items over the counter that have not been scanned yet.', 'trackfree-woocommerce-tracking'); ?>
                                                </p>
                                                <table class="trackfree-table">
                                                  <tbody>
                                                    <?php foreach ($shipment_data['unknownTracking'] as $tracking) { ?>
                                                      <tr>
                                                        <td><?php echo $tracking['trackingNum']; ?></td>
                                                        <td>
                                                            <img class="trackfree-courier-logo" src="<?php echo $tracking['courierLogo']; ?>" alt="<?php echo $tracking['courierName'];?>" />
                                                        </td>
                                                      </tr>
                                                  <?php } ?>
                                                  </tbody>
                                                </table>
                                            </div>
                                            <footer>
                                                <a href="javascript:void(0);" class="trackfree-modal-close"><?php _e('Close', 'trackfree-woocommerce-tracking'); ?>
                                                </a>
                                            </footer>
                                        </div>
                                    <?php } ?>
                                    <div>
                                        <div class="trackfree-wl-sm"><?php _e('Here is your shipment performance for the last 30 days', 'trackfree-woocommerce-tracking'); ?></div>
                                        <div class="trackfree-sp-cn">
                                            <div>
                                                <div class="trackfree-cl-pr" data-percent="<?php echo $shipment_data['averageDelivered'];?>">
                                                    <div class="trackfree-cl-in">
                                                        <div class="trackfree-rn-pr"></div>
                                                    </div>
                                                </div>
                                            </div>
                                            <div style="margin-left: 24px;">
                                                <div class="trackfree-sp-td"><?php _e('Total delivered', 'trackfree-woocommerce-tracking'); ?></div>
                                                <div class="trackfree-sp-dl">
                                                    <div class="trackfree-sp-dm"><?php echo $shipment_data['delivered'];?></div>
                                                    <div class="trackfree-sp-ds"><span style="margin: 0px 8px;">/</span><?php echo $shipment_data['totalShipments'];?> <?php $shipment_data['totalShipments'] > 1 ? _e('shipments', 'trackfree-woocommerce-tracking') : _e('shipment', 'trackfree-woocommerce-tracking'); ?></div>
                                                </div>
                                                <div style="margin-top: 12px;"><a class="trackfree-sp-sd" href="javascript:void();" data-tf-modal-id="ship-detail-modal"><?php _e('See details', 'trackfree-woocommerce-tracking'); ?></a></div>
                                                <div id="ship-detail-modal" class="trackfree-modal-box">
                                                    <header>
                                                        <a href="javascript:void(0);" class="trackfree-modal-close trackfree-close">X</a>
                                                        <h3><?php _e('Shipment details', 'trackfree-woocommerce-tracking'); ?></h3>
                                                    </header>
                                                    <div class="modal-body">
                                                        <?php
                                                        $s1 = $shipment_data['trackDetails'][0] ? $shipment_data['trackDetails'][0]['totalTrack'] : 0;
                                                        $s2 = $shipment_data['trackDetails'][1] ? $shipment_data['trackDetails'][1]['totalTrack'] : 0;
                                                        $s3 = $shipment_data['trackDetails'][2] ? $shipment_data['trackDetails'][2]['totalTrack'] : 0;
                                                        $s4 = $shipment_data['trackDetails'][5] ? $shipment_data['trackDetails'][5]['totalTrack'] : 0;
                                                        $s5 = $shipment_data['trackDetails'][4] ? $shipment_data['trackDetails'][4]['totalTrack'] : 0;
                                                        $s6 = $shipment_data['trackDetails'][3] ? $shipment_data['trackDetails'][3]['totalTrack'] : 0;
                                                        ?>
                                                        <div style="margin-top: 40px">
                                                            <div class="dash_progress_horizontal_line"></div>
                                                            <div class="trackfree-row dash_progress_stats">
                                                              <div class="tfreecol-2" style="padding-bottom:25px">
                                                                <span class="dash_progress_icon dash_progress_info"></span>
                                                                <p class="dash_progress_item_title"><?php _e('Info Received', 'trackfree-woocommerce-tracking'); ?></p>
                                                                <p class="dash_progress_item_percent"><?php echo $shipment_data['trackDetails'][0] ? $shipment_data['trackDetails'][0]['percentage'] : 0;?>%</p>
                                                                <p class="dash_progress_item_ship"><?php echo $s1; ?> <?php echo $s1 > 1 ? _e('shipments', 'trackfree-woocommerce-tracking') : _e('shipment', 'trackfree-woocommerce-tracking'); ?></p>
                                                              </div>
                                                              <div class="tfreecol-2" style="padding-bottom: 25px">
                                                                <span class="dash_progress_icon dash_progress_transit"></span>
                                                                <p class="dash_progress_item_title"><?php _e('In Transit', 'trackfree-woocommerce-tracking'); ?></p>
                                                                <p class="dash_progress_item_percent"><?php echo $shipment_data['trackDetails'][1] ? $shipment_data['trackDetails'][1]['percentage'] : 0;?>%</p>
                                                                <p class="dash_progress_item_ship"><?php echo $s2; ?> <?php echo $s2 > 1 ? _e('shipments', 'trackfree-woocommerce-tracking') : _e('shipment', 'trackfree-woocommerce-tracking'); ?></p>
                                                              </div>
                                                              <div class="tfreecol-2" style="padding-bottom: 25px">
                                                                <span class="dash_progress_icon dash_progress_out"></span>
                                                                <p class="dash_progress_item_title"><?php _e('Out For Delivery', 'trackfree-woocommerce-tracking'); ?></p>
                                                                <p class="dash_progress_item_percent"><?php echo $shipment_data['trackDetails'][2] ? $shipment_data['trackDetails'][2]['percentage'] : 0;?>%</p>
                                                                <p class="dash_progress_item_ship"><?php echo $s3; ?> <?php echo $s3 > 1 ? _e('shipments', 'trackfree-woocommerce-tracking') : _e('shipment', 'trackfree-woocommerce-tracking'); ?></p>
                                                              </div>
                                                              <div class="tfreecol-2" style="padding-bottom: 25px">
                                                                <span class="dash_progress_icon dash_progress_fail"></span>
                                                                <p class="dash_progress_item_title"><?php _e('Failed Attempt', 'trackfree-woocommerce-tracking'); ?></p>
                                                                <p class="dash_progress_item_percent"><?php echo $shipment_data['trackDetails'][5] ? $shipment_data['trackDetails'][5]['percentage'] : 0;?>%</p>
                                                                <p class="dash_progress_item_ship"><?php echo $s4; ?> <?php echo $s4 > 1 ? _e('shipments', 'trackfree-woocommerce-tracking') : _e('shipment', 'trackfree-woocommerce-tracking'); ?></p>
                                                              </div>
                                                              <div class="tfreecol-2" style="padding-bottom: 25px">
                                                                <span class="dash_progress_icon dash_progress_exep"></span>
                                                                <p class="dash_progress_item_title"><?php _e('Exception', 'trackfree-woocommerce-tracking'); ?></p>
                                                                <p class="dash_progress_item_percent"><?php echo $shipment_data['trackDetails'][4] ? $shipment_data['trackDetails'][4]['percentage'] : 0;?>%</p>
                                                                <p class="dash_progress_item_ship"><?php echo $s5; ?> <?php echo $s5 > 1 ? _e('shipments', 'trackfree-woocommerce-tracking') : _e('shipment', 'trackfree-woocommerce-tracking'); ?></p>
                                                              </div>
                                                              <div class="tfreecol-2" style="padding-bottom: 25px">
                                                                <span class="dash_progress_icon dash_progress_deliverd"></span>
                                                                <p class="dash_progress_item_title"><?php _e('Delivered', 'trackfree-woocommerce-tracking'); ?></p>
                                                                <p class="dash_progress_item_percent"><?php echo $shipment_data['trackDetails'][3] ? $shipment_data['trackDetails'][3]['percentage'] : 0;?>%</p>
                                                                <p class="dash_progress_item_ship"><?php echo $s6; ?> <?php echo $s6 > 1 ? _e('shipments', 'trackfree-woocommerce-tracking') : _e('shipment', 'trackfree-woocommerce-tracking'); ?></p>
                                                              </div>
                                                            </div>
                                                          </div>
                                                    </div>
                                                    <footer>
                                                        <a href="javascript:void(0);" class="trackfree-modal-close"><?php _e('Close', 'trackfree-woocommerce-tracking'); ?>
                                                        </a>
                                                    </footer>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <?php
                            }
                            ?>
                        </div>

                        <div class="trackfree-card" style="margin-top: 16px;">
                            <h2><?php echo __('Customer satisfaction', 'trackfree-woocommerce-tracking'); ?></h2>
                            <div id="show_shipment_survey"></div>
                        </div>
                        <div class="trackfree-card" style="margin-top: 16px;">
                            <h2><?php echo __('Top 5’s', 'trackfree-woocommerce-tracking'); ?></h2>
                            <div class="trackfree-tabs">
                                <div id="tf_tp_cr" class="trackfree-sl-tb">
                                    <?php _e('Couriers', 'trackfree-woocommerce-tracking'); ?>
                                </div>
                                <div id="tf_tp_dn" class="trackfree-tb-ct">
                                    <?php _e('Destination', 'trackfree-woocommerce-tracking'); ?>
                                </div>
                            </div>
                            <div class="trackfree-cr-ls">
                                <select id="courier_range">
                                    <option value="1"><?php _e('30 Days', 'trackfree-woocommerce-tracking'); ?></option>
                                    <option value="2"><?php _e('All', 'trackfree-woocommerce-tracking'); ?></option>
                                </select>
                            </div>
                            <div id="show_top_courier_data"></div>

                            <div class="trackfree-dn-ls" style="display: none;">
                                <select id="destination_range">
                                    <option value="1"><?php _e('30 Days', 'trackfree-woocommerce-tracking'); ?></option>
                                    <option value="2"><?php _e('All', 'trackfree-woocommerce-tracking'); ?></option>
                                </select>
                            </div>
                            <div id="show_top_destination_data" style="display: none;"></div>
                        </div>
                    </div>
                    <div class="trackfree-col-5">
                        <div class="trackfree-card">
                            <div>
                                <h2><?php _e('Activity', 'trackfree-woocommerce-tracking'); ?></h2>
                                <div class="trackfree-ls-tl"><?php _e('Live stream', 'trackfree-woocommerce-tracking'); ?></div>
                                <div class="trackfree-tabs">
                                    <div id="tf_ac_al" class="trackfree-sl-tb">
                                        <?php _e('All', 'trackfree-woocommerce-tracking'); ?>
                                    </div>
                                    <div id="tf_ac_fv" class="trackfree-tb-ct">
                                        <?php _e('Favorite', 'trackfree-woocommerce-tracking'); ?>
                                    </div>
                                </div>
                                <div class="trackfree-ac-ls">
                                    <select id="tf_activity_status">
                                        <option value=""><?php _e('All', 'trackfree-woocommerce-tracking'); ?></option>
                                        <option value="8"><?php _e('Pending', 'trackfree-woocommerce-tracking'); ?></option>
                                        <option value="1"><?php _e('Info Received', 'trackfree-woocommerce-tracking'); ?></option>
                                        <option value="2"><?php _e('In Transit', 'trackfree-woocommerce-tracking'); ?></option>
                                        <option value="3"><?php _e('Out For Delivery', 'trackfree-woocommerce-tracking'); ?></option>
                                        <option value="4"><?php _e('Delivered', 'trackfree-woocommerce-tracking'); ?></option>
                                        <option value="5"><?php _e('Exception', 'trackfree-woocommerce-tracking'); ?></option>
                                        <option value="6"><?php _e('Failed Attempt', 'trackfree-woocommerce-tracking'); ?></option>
                                        <option value="7"><?php _e('Expired', 'trackfree-woocommerce-tracking'); ?></option>
                                    </select>
                                </div>
                            </div>
                            <div id="show_activity_data" style="margin-top: 16px;"></div>
                            <div id="show_fav_activity_data" style="margin-top: 16px; display: none;"></div>
                        </div>

                        <div class="trackfree-plan-card" style="margin-top: 16px; padding-bottom: 24px;">
                            <div>
                                <h2 style="padding: 24px 16px 0 16px;"><?php _e('Need any help?', 'trackfree-woocommerce-tracking'); ?></h2>
                                <div>
                                    <div class="trackfree-hp-ct" id="tf_hp_ml">
                                        <div class="trackfree-hl-ic">
                                            <img class="icon" src="<?php echo plugins_url('/trackfree-woocommerce-tracking/assets/icons/email.svg'); ?>">
                                        </div>
                                        <div>
                                            <div class="trackfree-hp-tl"><?php _e('Get Email Support', 'trackfree-woocommerce-tracking'); ?></div>
                                            <div><?php _e('Send us an email, and we will respond as soon as possible.', 'trackfree-woocommerce-tracking'); ?></div>
                                        </div>
                                    </div>
                                    <div class="trackfree-hp-ct" id="tf_hp_ct">
                                        <div class="trackfree-hl-ic">
                                            <img class="icon" src="<?php echo plugins_url('/trackfree-woocommerce-tracking/assets/icons/chat.svg'); ?>">
                                        </div>
                                        <div>
                                            <div class="trackfree-hp-tl"><?php _e('Start Live Chat', 'trackfree-woocommerce-tracking'); ?></div>
                                            <div><?php _e('Chat with us live to get help with your question.', 'trackfree-woocommerce-tracking'); ?></div>
                                        </div>
                                    </div>
                                    <div class="trackfree-hp-ct" id="tf_hp_dc">
                                        <div class="trackfree-hl-ic">
                                            <img class="icon" src="<?php echo plugins_url('/trackfree-woocommerce-tracking/assets/icons/happy.svg'); ?>">
                                        </div>
                                        <div>
                                            <div class="trackfree-hp-tl"><?php _e('TrackFree Help Docs', 'trackfree-woocommerce-tracking'); ?></div>
                                            <div><?php _e('Find a solution for your problem with TrackFree documents and tutorials.', 'trackfree-woocommerce-tracking'); ?></div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <?php
    }

    add_action( 'wp_ajax_get_shipment_survey', 'get_shipment_survey' );

    function get_shipment_survey()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            $trackfree_account_api_key = get_option('trackfree_account_api_key');
            $trackfree_account_verify = get_option('trackfree_account_verify');

            if (($trackfree_account_api_key) && ($trackfree_account_verify)) {
                $request = array(
                    'key' => $trackfree_account_api_key,
                    'range' => $_POST['range']
                );
                $survey_response = wp_remote_get(trackfree_url() . '/api/wc_shipment_survey',
                array(
                    'sslverify' => false,
                    'timeout' => 15,
                    'body' => $request
                ));
                $survey_data = json_decode( wp_remote_retrieve_body( $survey_response ), true );
                if ($survey_data['status'] == 'success') { ?>
                    <div>
                        <div style="padding: 16px 24px;">
                            <div class="trackfree-cs-tr">
                                <div class="trackfree-cs-to">
                                    <div class="trackfree-wc-sm"><?php _e('Total Respondent', 'trackfree-woocommerce-tracking'); ?></div>
                                    <div class="trackfree-sv-tl"><?php echo $survey_data['survey']['total'];?></div>
                                </div>
                                <div class="trackfree-sv-rn">
                                    <select id="survey_range">
                                        <option value="1" <?php if ($_POST['range'] == 1) { ?>selected<?php } ?>><?php _e('30 Days', 'trackfree-woocommerce-tracking'); ?></option>
                                        <option value="2" <?php if ($_POST['range'] == 2) { ?>selected<?php } ?>><?php _e('90 Days', 'trackfree-woocommerce-tracking'); ?></option>
                                        <option value="3" <?php if ($_POST['range'] == 3) { ?>selected<?php } ?>><?php _e('All', 'trackfree-woocommerce-tracking'); ?></option>
                                    </select>
                                </div>
                            </div>
                            <div>
                                <div class="trackfree-sv-rp">
                                    <div class="trackfree-sv-dt">
                                        <p class="trackfree-pn-tl"><?php _e('Satisfied', 'trackfree-woocommerce-tracking'); ?></p>
                                        <span class="trackfree-hp-ic"></span>
                                        <div><?php echo $survey_data['survey']['satisfied'];?></div>
                                    </div>
                                    <div class="trackfree-sv-dt">
                                        <p class="trackfree-pn-tl"><?php _e('Not satisfied', 'trackfree-woocommerce-tracking'); ?></p>
                                        <span class="trackfree-sd-ic"></span>
                                        <div><?php echo $survey_data['survey']['notSatisfied'];?></div>
                                    </div>
                                </div>
                                <div style="text-align: center;">
                                    <p class="trackfree-cs-hd"><?php _e('Automated Satisfaction Survey', 'trackfree-woocommerce-tracking'); ?></p>
                                    <p class="trackfree-cs-ds"><?php _e('We send a simple survey to every customer after they have received their order (subject to a frequency limit you choose), so you can ensure satisfaction every time.', 'trackfree-woocommerce-tracking'); ?></p>
                                    <button type="button" class="button" id="download_survey">
                                        <span>
                                            <span><?php _e('Download Report', 'trackfree-woocommerce-tracking'); ?></span>
                                        </span>
                                    </button>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php
                }
            }
        }
        wp_die();
    }

    add_action( 'wp_ajax_get_top_couriers', 'get_top_couriers' );

    function get_top_couriers()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            $trackfree_account_api_key = get_option('trackfree_account_api_key');
            $trackfree_account_verify = get_option('trackfree_account_verify');

            if (($trackfree_account_api_key) && ($trackfree_account_verify)) {
                $request = array(
                    'key' => $trackfree_account_api_key,
                    'range' => $_POST['range']
                );
                $courier_response = wp_remote_get(trackfree_url() . '/api/wc_top_couriers',
                array(
                    'sslverify' => false,
                    'timeout' => 15,
                    'body' => $request
                ));
                $courier_data = json_decode( wp_remote_retrieve_body( $courier_response ), true );
                if ($courier_data['status'] == 'success') {
                    if (sizeof($courier_data['topCouriers']) > 0) {
                        foreach ($courier_data['topCouriers'] as $courier) { ?>
                            <div class="trackfree-tp-ls">
                                <div>
                                    <img class="trackfree-courier-logo" src="<?php echo $courier['courierLogo'];?>" alt="<?php echo $courier['courierName'];?>" />
                                </div>
                                <div style="margin-top: 8px;">
                                    <?php echo $courier['shipments'];?> <?php echo $courier['shipments'] > 1 ? _e('shipments', 'trackfree-woocommerce-tracking') : _e('shipment', 'trackfree-woocommerce-tracking'); ?>
                                </div>
                            </div>
                            <?php
                        }
                    } else {
                        echo '<div class="trackfree-no-ac">' . __('No data found', 'trackfree-woocommerce-tracking') .'</div>';
                    }
                }
            }
        }
        wp_die();
    }

    add_action( 'wp_ajax_get_top_destinations', 'get_top_destinations' );

    function get_top_destinations()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            $trackfree_account_api_key = get_option('trackfree_account_api_key');
            $trackfree_account_verify = get_option('trackfree_account_verify');

            if (($trackfree_account_api_key) && ($trackfree_account_verify)) {
                $request = array(
                    'key' => $trackfree_account_api_key,
                    'range' => $_POST['range']
                );
                $destination_response = wp_remote_get(trackfree_url() . '/api/wc_top_destinations',
                array(
                    'sslverify' => false,
                    'timeout' => 15,
                    'body' => $request
                ));
                $destination_data = json_decode( wp_remote_retrieve_body( $destination_response ), true );
                if ($destination_data['status'] == 'success') {
                    if (sizeof($destination_data['topDestinations']) > 0) {
                        foreach ($destination_data['topDestinations'] as $destination) { ?>
                            <div class="trackfree-tp-dn">
                                <div style="width: 50%; padding-right: 16px;">
                                    <?php echo $destination['countryName'];?>
                                </div>
                                <div style="width: 50%;">
                                    <?php echo $destination['shipments'];?> <?php echo $destination['shipments'] > 1 ? _e('shipments', 'trackfree-woocommerce-tracking') : _e('shipment', 'trackfree-woocommerce-tracking'); ?>
                                </div>
                            </div>
                            <?php
                        }
                    } else {
                        echo '<div class="trackfree-no-ac">' . __('No data found', 'trackfree-woocommerce-tracking') .'</div>';
                    }
                }
            }
        }
        wp_die();
    }

    add_action( 'wp_ajax_download_shipment_survey', 'download_shipment_survey' );

    function download_shipment_survey()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            $trackfree_account_api_key = get_option('trackfree_account_api_key');
            $trackfree_account_verify = get_option('trackfree_account_verify');

            if (($trackfree_account_api_key) && ($trackfree_account_verify)) {
                $request = array(
                    'key' => $trackfree_account_api_key
                );
                $survey_response = wp_remote_get(trackfree_url() . '/api/wc_download_shipment_survey',
                array(
                    'sslverify' => false,
                    'timeout' => 15,
                    'body' => $request
                ));
                $survey_data = json_decode( wp_remote_retrieve_body( $survey_response ), true );
                if ($survey_data['status'] == 'success') {
                    echo $survey_data['downloadLink'];
                }
            }
        }
        wp_die();
    }

    add_action( 'wp_ajax_get_tracking_activity', 'get_tracking_activity' );

    function get_tracking_activity()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            $trackfree_account_api_key = get_option('trackfree_account_api_key');
            $trackfree_account_verify = get_option('trackfree_account_verify');

            if (($trackfree_account_api_key) && ($trackfree_account_verify)) {
                $request = array(
                    'key' => $trackfree_account_api_key,
                    'type' => $_POST['status_type']
                );
                $activity_response = wp_remote_get(trackfree_url() . '/api/wc_activity',
                array(
                    'sslverify' => false,
                    'timeout' => 15,
                    'body' => $request
                ));
                $activity_data = json_decode( wp_remote_retrieve_body( $activity_response ), true );
                if ($activity_data['status'] == 'success') {
                    if (sizeof($activity_data['activity']) > 0) {
                        foreach ($activity_data['activity'] as $activity) { ?>
                            <div class="trackfree-ls-im">
                                <div class="trackfree-al-av">
                                    <img class="trackfree-courier-logo" src="<?php echo $activity['courierLogo'];?>" alt="<?php echo $activity['courierName'];?>" />
                                </div>
                                <div>
                                    <div class="trackfree-al-td">
                                        <div class="trackfree-al-tn"><?php echo $activity['trackingNum'];?></div>
                                        <div>
                                            <span class="track_<?php echo str_replace(' ', '_', $activity['trackStatus'])?> trackfree_track_status"><?php echo $activity['trackStatus'];?></span>
                                        </div>
                                    </div>
                                    <div class="trackfree-al-od"><?php echo $activity['customerName'];?>
                                        <?php if ($activity['orderId']) { ?>
                                        <span> | </span><?php } ?>
                                         <?php echo $activity['orderId'];?></div>
                                </div><div class="trackfree-al-tm"><?php echo $activity['trackDate'];?></div>
                            </div>
                            <?php
                        }
                    } else {
                        echo '<div class="trackfree-no-ac">' . __('No activity found', 'trackfree-woocommerce-tracking') .'</div>';
                    }
                }
            }
        }
        wp_die();
    }

    add_action( 'wp_ajax_get_tracking_fav_activity', 'get_tracking_fav_activity' );

    function get_tracking_fav_activity()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            $trackfree_account_api_key = get_option('trackfree_account_api_key');
            $trackfree_account_verify = get_option('trackfree_account_verify');

            if (($trackfree_account_api_key) && ($trackfree_account_verify)) {
                $request = array(
                    'key' => $trackfree_account_api_key,
                    'type' => $_POST['status_type']
                );
                $activity_response = wp_remote_get(trackfree_url() . '/api/wc_fav_activity',
                array(
                    'sslverify' => false,
                    'timeout' => 15,
                    'body' => $request
                ));
                $activity_data = json_decode( wp_remote_retrieve_body( $activity_response ), true );
                if ($activity_data['status'] == 'success') {
                    if (sizeof($activity_data['activity']) > 0) {
                        foreach ($activity_data['activity'] as $activity) { ?>
                            <div class="trackfree-ls-im">
                                <div class="trackfree-al-av">
                                    <img class="trackfree-courier-logo" src="<?php echo $activity['courierLogo'];?>" alt="<?php echo $activity['courierName'];?>" />
                                </div>
                                <div>
                                    <div class="trackfree-al-td">
                                        <div class="trackfree-al-tn"><?php echo $activity['trackingNum'];?></div>
                                        <div>
                                            <span class="track_<?php echo str_replace(' ', '_', $activity['trackStatus'])?> trackfree_track_status"><?php echo $activity['trackStatus'];?></span>
                                        </div>
                                    </div>
                                    <div class="trackfree-al-od"><?php echo $activity['customerName'];?>
                                        <?php if ($activity['orderId']) { ?>
                                        <span> | </span><?php } ?>
                                         <?php echo $activity['orderId'];?></div>
                                </div><div class="trackfree-al-tm"><?php echo $activity['trackDate'];?></div>
                            </div>
                            <?php
                        }
                    } else {
                        echo '<div class="trackfree-no-ac">' . __('No activity found', 'trackfree-woocommerce-tracking') .'</div>';
                    }
                }
            }
        }
        wp_die();
    }

    add_action( 'wp_ajax_dismiss_track_page_info', 'dismiss_track_page_info' );

    function dismiss_track_page_info()
    {
        update_option('trackfree_hide_track_page_info', 1);
        wp_die();
    }
}
?>
