<?php
if (!defined( 'ABSPATH'))
    exit;

if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    function trackfree_shipment_status($id)
    {
        $status = [
            0 => 'pending',
            1 => 'info_received',
            2 => 'transit',
            3 => 'pickup',
            4 => 'delivered',
            5 => 'exception',
            6 => 'undelivered',
            7 => 'expired',
        ];
        return $status[$id] ?? null;
    }

    function trackfree_shipments_page()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            $trackfree_account_api_key = get_option('trackfree_account_api_key');
            $trackfree_account_verify = get_option('trackfree_account_verify');

            $appVerifyContent = '';

            if ($trackfree_account_api_key == '') {
                include ('getting-started.php');
            }
            if (($trackfree_account_api_key) && ($trackfree_account_verify == 0)) {
                $appVerifyContent = '<div class="trackfree-error-container">' . __('Your app is not verified. Click verify link and activate your app in your mail. Please refresh this page if you have already verified.', 'trackfree-woocommerce-tracking') . '</div>';
                include ('getting-started.php');
            }

            if (($trackfree_account_verify == 0) && ($trackfree_account_api_key)) {
                trackfree_verification_status();
            }

            if (($trackfree_account_api_key) && ($trackfree_account_verify)) {
                trackfree_shipments_page_action();
            }
        }
    }

    function trackfree_shipments_page_action()
    {
        $nonce = wp_create_nonce( 'TrackFree' );
        $trackfree_account_api_key = get_option('trackfree_account_api_key');

        $page = isset($_GET['p']) ? $_GET['p'] : 1;

        $post_data = array(
            'status' => isset($_GET['status']) ? $_GET['status'] : '',
            'search_by' => isset($_GET['search_by']) ? $_GET['search_by'] : '',
            'date_range' => isset($_GET['date_range']) ? $_GET['date_range'] : '',
            'courier' => isset($_GET['courier']) ? $_GET['courier'] : '',
            'page' => $page,
        );

        $response = wp_remote_post(trackfree_url() . '/api/wc_shipments?key=' . $trackfree_account_api_key,
        array(
            'sslverify' => false,
            'timeout' => 15,
            'body' => $post_data
            )
        );
        $response_data = json_decode( wp_remote_retrieve_body( $response ), true );

        $url = 'admin.php?page=trackfree-shipments';
        $url_params = 'admin.php?page=trackfree-shipments';
        if (isset($_GET['status'])) {
            $url_params .= '&status=' . $_GET['status'];
        }
        if (isset($_GET['search_by'])) {
            $url_params .= '&search_by=' . $_GET['search_by'];
        }
        if (isset($_GET['date_range'])) {
            $url_params .= '&date_range=' . $_GET['date_range'];
        }
        if (isset($_GET['courier'])) {
            $url_params .= '&courier=' . $_GET['courier'];
        }
        ?>
        <div class="wrap">
            <div style="display: flex; align-items: center;">
                <h1 class="wp-heading-inline"><?php _e('Shipments', 'trackfree-woocommerce-tracking');?></h1>
            </div>
            <p class="nav-tab-wrapper"></p>
            <div style="clear:both;"></div>
            <div id="trackfree-shipment-details"></div>
            <?php if ($response_data && $response_data['status'] == 'success') { ?>
                <div class="trackfree-sl-wp">
                    <div>
                        <ul class="subsubsub trackfree-st-ls">
                            <li><a href="<?php echo $url;?>" <?php if (empty($_GET['status'])) { ?>class="current"<?php } ?>><?php _e("All", 'trackfree-woocommerce-tracking');?> <span class="count">(<?php echo $response_data['allShipments'];?>)</span></a> |</li>
                            <li><a href="<?php echo $url;?>&status=1" <?php if (isset($_GET['status']) && $_GET['status'] == 1) { ?>class="current"<?php } ?>><?php _e("Pending", 'trackfree-woocommerce-tracking');?> <span class="count">(<?php echo $response_data['pending'];?>)</span></a> |</li>
                            <li><a href="<?php echo $url;?>&status=2" <?php if (isset($_GET['status']) && $_GET['status'] == 2) { ?>class="current"<?php } ?>><?php _e("Info Received", 'trackfree-woocommerce-tracking');?> <span class="count">(<?php echo $response_data['infoReceived'];?>)</span></a> |</li>
                            <li><a href="<?php echo $url;?>&status=3" <?php if (isset($_GET['status']) && $_GET['status'] == 3) { ?>class="current"<?php } ?>><?php _e("In Transit", 'trackfree-woocommerce-tracking');?> <span class="count">(<?php echo $response_data['inTransit'];?>)</span></a> |</li>
                            <li><a href="<?php echo $url;?>&status=4" <?php if (isset($_GET['status']) && $_GET['status'] == 4) { ?>class="current"<?php } ?>><?php _e("Out For Delivery", 'trackfree-woocommerce-tracking');?> <span class="count">(<?php echo $response_data['outForDelivery'];?>)</span></a> |</li>
                            <li><a href="<?php echo $url;?>&status=5" <?php if (isset($_GET['status']) && $_GET['status'] == 5) { ?>class="current"<?php } ?>><?php _e("Delivered", 'trackfree-woocommerce-tracking');?> <span class="count">(<?php echo $response_data['delivered'];?>)</span></a> |</li>
                            <li><a href="<?php echo $url;?>&status=6" <?php if (isset($_GET['status']) && $_GET['status'] == 6) { ?>class="current"<?php } ?>><?php _e("Exception", 'trackfree-woocommerce-tracking');?> <span class="count">(<?php echo $response_data['exception'];?>)</span></a> |</li>
                            <li><a href="<?php echo $url;?>&status=7" <?php if (isset($_GET['status']) && $_GET['status'] == 7) { ?>class="current"<?php } ?>><?php _e("Failed Attempt", 'trackfree-woocommerce-tracking');?> <span class="count">(<?php echo $response_data['failedAttempt'];?>)</span></a> |</li>
                            <li><a href="<?php echo $url;?>&status=8" <?php if (isset($_GET['status']) && $_GET['status'] == 8) { ?>class="current"<?php } ?>><?php _e("Expired", 'trackfree-woocommerce-tracking');?> <span class="count">(<?php echo $response_data['expired'];?>)</span></a></li>
                        </ul>
                    </div>
                    <div style="clear:both;"></div>
                    <div class="trackfree-fl-wp">
                        <form method="get" action="<?php echo admin_url($url_params);?>">
                            <input type="hidden" name="page" value="trackfree-shipments" />
                            <div class="trackfree_sp-fm">
                                <div style="margin-right: 8px;">
                                    <input type="text" name="search_by" id="search_by" value="<?php echo isset($_GET['search_by']) ? $_GET['search_by'] : '';?>" class="regular-text" placeholder="<?php _e("Filter order number or Tracking number", 'trackfree-woocommerce-tracking');?>" />
                                </div>
                                <div style="margin-right: 8px;">
                                    <select name="date_range">
                                        <option value="1" <?php if (isset($_GET['date_range']) && $_GET['date_range'] == 1) { ?>selected="selected"<?php } ?>><?php _e("Today", 'trackfree-woocommerce-tracking');?></option>
                                        <option value="7" <?php if (isset($_GET['date_range']) && $_GET['date_range'] == 7) { ?>selected="selected"<?php } ?>><?php echo sprintf(esc_html__('Last %1$s days', 'trackfree-woocommerce-tracking'), '7'); ?></option>
                                        <option value="30" <?php if (isset($_GET['date_range']) && $_GET['date_range'] == 30) { ?>selected="selected"<?php } ?>><?php echo sprintf(esc_html__('Last %1$s days', 'trackfree-woocommerce-tracking'), '30'); ?></option>
                                        <option value="60" <?php if ((isset($_GET['date_range']) && $_GET['date_range'] == 60) || empty($_GET['date_range'])) { ?>selected="selected"<?php } ?>><?php echo sprintf(esc_html__('Last %1$s days', 'trackfree-woocommerce-tracking'), '60'); ?></option>
                                        <option value="90" <?php if (isset($_GET['date_range']) && $_GET['date_range'] == 90) { ?>selected="selected"<?php } ?>><?php echo sprintf(esc_html__('Last %1$s days', 'trackfree-woocommerce-tracking'), '90'); ?></option>
                                    </select>
                                </div>
                                <div style="margin-right: 8px;">
                                    <select name="courier">
                                        <option value="" selected="selected"><?php _e('Filter by courier', 'trackfree-woocommerce-tracking');?></option>
                                        <?php foreach ($response_data['couriers'] as $courier) { ?>
                                            <option value="<?php echo $courier['name'];?>" <?php if (isset($_GET['courier']) && $_GET['courier'] == $courier['name']) { ?>selected="selected"<?php } ?>><?php echo $courier['title'];?></option>
                                        <?php } ?>
                                    </select>
                                </div>
                                <div>
                                    <button type="submit" class="button button-primary"><?php _e('Filter', 'trackfree-woocommerce-tracking'); ?></button>
                                </div>
                                <div class="trackfree-sh-rs">
                                    <div class="tablenav-pages">
                                        <span class="displaying-num">
                                            <?php echo sprintf(esc_html__('Showing %1$s shipments', 'trackfree-woocommerce-tracking'), $response_data['totalShipments']); ?>
                                        </span>
                                        <?php if ($response_data['totalPages'] > 1) { ?>
                                            <span class="pagination-links" style="margin-left: 8px;">
                                                <?php if ($page != 1) {
                                                    $prevPage = $page - 1; ?>
                                                    <a href="<?php echo $url_params;?>" class="first-page button">
                                                        <span class="screen-reader-text"><?php _e('First page', 'trackfree-woocommerce-tracking'); ?></span>
                                                        <span aria-hidden="true">«</span>
                                                    </a>
                                                    <a href="<?php echo $url_params . '&p=' . $prevPage;?>" class="prev-page button">
                                                        <span class="screen-reader-text"><?php _e('Previous page', 'trackfree-woocommerce-tracking'); ?></span>
                                                        <span aria-hidden="true">‹</span>
                                                    </a>
                                                <?php } else { ?>
                                                    <span aria-hidden="true" class="tablenav-pages-navspan button disabled">«</span>
                                                    <span aria-hidden="true" class="tablenav-pages-navspan button disabled">‹</span>
                                                <?php } ?>
                                                <span class="paging-input" style="margin: 0 4px;">
                                                    <label for="current-page-selector" class="screen-reader-text"><?php _e('Current page', 'trackfree-woocommerce-tracking'); ?></label>
                                                    <input id="current-page-selector" type="text" name="p" value="<?php echo $page;?>" size="1" aria-describedby="table-paging" class="current-page">
                                                    <span class="tablenav-paging-text"> of <span class="total-pages"><?php echo $response_data['totalPages'];?></span></span>
                                                </span>
                                                <?php if ($page == $response_data['totalPages']) { ?>
                                                    <span aria-hidden="true" class="tablenav-pages-navspan button disabled">›</span>
                                                    <span aria-hidden="true" class="tablenav-pages-navspan button disabled">»</span>
                                                <?php } else {
                                                    $nextPage = $page + 1; ?>
                                                    <a href="<?php echo $url_params . '&p=' . $nextPage;?>" class="next-page button"><span class="screen-reader-text"><?php _e('Next page', 'trackfree-woocommerce-tracking'); ?></span><span aria-hidden="true">›</span></a>
                                                    <a href="<?php echo $url_params . '&p=' . $response_data['totalPages'];?>" class="last-page button"><span class="screen-reader-text"><?php _e('Last page', 'trackfree-woocommerce-tracking'); ?></span><span aria-hidden="true">»</span></a>
                                                <?php } ?>
                                            </span>
                                        <?php } ?>
                                    </div>
                                </div>
                            </div>
                        </form>
                    </div>
                    <div class="trackfree-tb-wp">
                        <table class="trackfree-sp-tb">
                            <thead>
                                <th style="width: 7%"><?php _e('Date', 'trackfree-woocommerce-tracking'); ?></th>
                                <th style="width: 10%"><?php _e('Order', 'trackfree-woocommerce-tracking'); ?></th>
                                <th style="width: 13%"><?php _e('Customer Name', 'trackfree-woocommerce-tracking'); ?></th>
                                <th style="width: 20%"><?php _e('Tracking Number', 'trackfree-woocommerce-tracking'); ?></th>
                                <th style="width: 10%"><?php _e('Status', 'trackfree-woocommerce-tracking'); ?></th>
                                <th style="width: 10%"><?php _e('Destination', 'trackfree-woocommerce-tracking'); ?></th>
                                <th style="width: 30%"><?php _e('Last Checkpoint', 'trackfree-woocommerce-tracking'); ?></th>
                            </thead>
                            <tbody>
                                <?php
                                if (sizeof($response_data['shipments']) > 0) {
                                    foreach ($response_data['shipments'] as $shipment) {
                                        if ($shipment['orderId']) {
                                            $order = wc_get_order($shipment['orderId']);
                                            if (is_callable([$order, 'get_edit_order_url'])) {
                                                $orderUrl = $order->get_edit_order_url();
                                                $orderId = '<span title="#' . $shipment['orderId'] . '"><a href="' . $orderUrl . '" style="text-decoration: none;">#' . $shipment['orderId'] . '</a></span>';
                                            } else {
                                                $orderId = $shipment['orderId'] ? '<span title="#' . $shipment['orderId'] . '">#' . $shipment['orderId'] . '</span>' : '';
                                            }
                                        } else {
                                            $orderId = $shipment['orderId'] ? '<span title="#' . $shipment['orderId'] . '">#' . $shipment['orderId'] . '</span>' : '';
                                        } ?>
                                        <tr>
                                            <td><span title="<?php echo $shipment['orderDate'];?>"><?php echo $shipment['orderDate'];?></span></td>
                                            <td><?php echo $orderId; ?></td>
                                            <td><span title="<?php echo $shipment['customerName'];?>"><?php echo $shipment['customerName'];?></span></td>
                                            <td>
                                                <a href="javascript:void(0);" class="trackfree-ship-row" id="<?php echo $shipment['trackingNumber'];?>" style="text-decoration: none;"><span title="<?php echo $shipment['trackingNumber']; ?>"><?php echo $shipment['trackingNumber']; ?></span></a>
                                                <br />
                                                <span title="<?php echo $shipment['courier'];?>"><?php echo $shipment['courier'];?></span>
                                            </td>
                                            <td><span class="trackfree-tracking-icon icon-<?php echo trackfree_shipment_status($shipment['currentStatus']);?>"><?php echo $shipment['status'];?></span></td>
                                            <td><span title="<?php echo $shipment['destination'];?>"><?php echo $shipment['destination'];?></span></td>
                                            <td><span title="<?php echo $shipment['lastCheckpoint'];?>"><?php echo $shipment['lastCheckpoint'];?></span></td>
                                        </tr>
                                        <?php
                                    }
                                } else { ?>
                                    <td colspan="7"><?php _e('No data found', 'trackfree-woocommerce-tracking'); ?></td>
                                    <?php
                                } ?>
                            </tbody>
                        </table>
                    </div>
                </div>
                <?php
            }?>
        </div>
        <?php
    }

    add_action( 'wp_ajax_update_tracking_favorite', 'update_tracking_favorite' );

    function update_tracking_favorite()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            $trackfree_account_api_key = get_option('trackfree_account_api_key');
            $trackfree_account_verify = get_option('trackfree_account_verify');

            if (($trackfree_account_api_key) && ($trackfree_account_verify)) {
                $request = array(
                    'key' => $trackfree_account_api_key,
                    'tracking_num' => $_POST['tracking_num'],
                    'fav_type' => $_POST['fav_type']
                );
                wp_remote_get(trackfree_url() . '/api/wc_favorite',
                array(
                    'sslverify' => false,
                    'timeout' => 15,
                    'body' => $request
                ));
            }
        }
    }

    add_action( 'wp_ajax_get_shipment_details', 'get_shipment_details' );

    function get_shipment_details()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            $trackfree_account_api_key = get_option('trackfree_account_api_key');
            $trackfree_account_verify = get_option('trackfree_account_verify');

            if (($trackfree_account_api_key) && ($trackfree_account_verify)) {
                $request = array(
                    'key' => $trackfree_account_api_key,
                    'tracking_num' => $_POST['tracking_num']
                );
                $track_response = wp_remote_get(trackfree_url() . '/api/wc_track_detail',
                array(
                    'sslverify' => false,
                    'timeout' => 15,
                    'body' => $request
                ));
                $track_data = json_decode( wp_remote_retrieve_body( $track_response ), true );
                $fav_class = $track_data['favorite'] == 1 ?  'trackfree_fav_on' : 'trackfree_fav_off';
                ?>
                <div class="trackfree-ship-card">
                    <div class="trackfree-tk-dv">
                        <div title="Back" class="trackfree-bc-ic"></div>
                        <span class="trackfree_linkout_harness" onclick="window.open('<?php echo trackfree_track_page_url($track_data['trackingNum']);?>')">
                            <div style="display: flex; align-items: center;">
                                <span class="trackfree-link"><?php _e('Tracking Page', 'trackfree-woocommerce-tracking');?></span>
                                <span class="trackfree_head_linkout"/>
                            </div>
                        </span>
                        <div></div>
                    </div>
                    <div class="trackfree-tr-de">
                        <div class="trackfree-tk-av">
                            <img class="trackfree-courier-logo" src="<?php echo $track_data['courierLogo']; ?>" alt="<?php echo $track_data['courierCaption'];?>" />
                        </div>
                        <div>
                            <div>
                                <span class="trackfree_head_tracking" id="<?php echo $track_data['trackingNum'];?>"><?php echo $track_data['trackingNum'];?></span>
                                <span class="<?php echo $fav_class;?>" id="tf_fv_ac"></span>
                            </div>
                            <span class="trackfree_head_name">
                                <div>
                                    <?php echo $track_data['shipmentDetails']['orderId'];?>
                                    <?php if ($track_data['shipmentDetails']['orderId'] && $track_data['shipmentDetails']['customerName']) { ?> | <?php } ?>
                                    <?php echo $track_data['shipmentDetails']['customerName'];?></div>
                            </span>
                        </div>
                    </div>
                    <div class="trackfree-dt-ct">
                        <div>
                            <p class="trackfree_mid_head"><?php _e('Status', 'trackfree-woocommerce-tracking');?></p>
                            <p class="trackfree_mid_detail"><?php echo $track_data['status'];?></p>
                        </div>
                        <div>
                            <p class="trackfree_mid_head"><?php _e('Schedule', 'trackfree-woocommerce-tracking');?></p>
                            <p class="trackfree_mid_detail"><?php echo $track_data['estimateDeliveryDate'] ? $track_data['estimateDeliveryDate'] : 'N/A';?></p>
                        </div>
                        <div>
                            <p class="trackfree_mid_head"><?php _e('Feedback', 'trackfree-woocommerce-tracking');?></p>
                            <p class="trackfree_mid_detail"><?php echo $track_data['feedback'] ? $track_data['feedback'] : 'N/A';?></p>
                        </div>
                    </div>
                    <div class="trackfree-tabs">
                        <div id="tf_tk_st" class="trackfree-sl-tb">
                            <?php _e('Status', 'trackfree-woocommerce-tracking'); ?>
                        </div>
                        <div id="tf_tk_dt" class="trackfree-tb-ct">
                            <?php _e('Details', 'trackfree-woocommerce-tracking'); ?>
                        </div>
                        <div id="tf_tk_cs" class="trackfree-tb-ct">
                            <?php _e('Customer Service', 'trackfree-woocommerce-tracking'); ?>
                        </div>
                        <div id="tf_tk_nf" class="trackfree-tb-ct">
                            <?php _e('Notifications', 'trackfree-woocommerce-tracking'); ?>
                        </div>
                    </div>
                    <div id="tf_st_ct">
                        <div style="padding: 24px 0;">
                            <?php if (isset($track_data['trackDetails']['trackValues']) && sizeof($track_data['trackDetails']['trackValues']) > 0) { ?>
                                <div>
                                    <table style="width: 90%;">
                                        <tbody>
                                            <?php foreach ($track_data['trackDetails']['trackValues'] as $item) { ?>
                                                <tr>
                                                  <td style="width:10%;"><span class="trackfree_status_pointer"></span>
                                                  </td>
                                                  <td style="width: 20%; text-align: center; padding: 10px 0px 10px 0px;">
                                                      <span class="trackfree_status_date"><?php echo $item['dateTime'];?></span>
                                                  </td>
                                                  <td style="width: 70%; padding: 10px 20px 10px 10px;">
                                                    <div>
                                                        <span class="trackfree_status_detail">
                                                            <?php echo $item['statusDescription'];?>
                                                        </span>
                                                    </div>
                                                    <div>
                                                      <span class="trackfree_status_city"><?php echo $item['city'];?></span>
                                                      <?php if ($item['isLocationModified']) { ?> <span class="trackfree_status_city" style="margin-left: 4px"><?php echo __('(Custom location applied)'); ?></span><?php } ?>
                                                    </div>
                                                  </td>
                                                </tr>
                                            <?php } ?>
                                        </tbody>
                                    </table>
                                </div>
                            <?php } else { ?>
                                <div style="margin: 24px 16px;"><?php _e('No tracking details are available', 'trackfree-woocommerce-tracking');?></div>
                                <?php
                            } ?>
                        </div>
                    </div>
                    <div id="tf_dt_ct" style="display: none;">
                        <div style="padding: 32px 16px;">
                            <div class="trackfree-dt-ls">
                                <span class="trackfree_details_label"><?php echo __('Created', 'trackfree-woocommerce-tracking');?></span>
                                <div><?php echo isset($track_data['shipmentDetails']['createdAt']) && $track_data['shipmentDetails']['createdAt'] ? $track_data['shipmentDetails']['createdAt'] : '';?></div>
                            </div>

                            <div class="trackfree-dt-ls">
                                <span class="trackfree_details_label"><?php echo __('Last Update', 'trackfree-woocommerce-tracking');?></span>
                                <div><?php echo isset($track_data['shipmentDetails']['updatedAt']) && $track_data['shipmentDetails']['updatedAt'] ? $track_data['shipmentDetails']['updatedAt'] : '';?></div>
                            </div>

                            <div class="trackfree-dt-ls">
                                <span class="trackfree_details_label"><?php echo __('Tracking Title', 'trackfree-woocommerce-tracking');?></span>
                                <div><?php echo isset($track_data['shipmentDetails']['trackingTitle']) && $track_data['shipmentDetails']['trackingTitle'] ? $track_data['shipmentDetails']['trackingTitle'] : '';?></div>
                            </div>

                            <div class="trackfree-dt-ls">
                                <span class="trackfree_details_label"><?php echo __('Order', 'trackfree-woocommerce-tracking');?> #</span>
                                <div><?php echo isset($track_data['shipmentDetails']['createdAt']) && $track_data['shipmentDetails']['createdAt'] ? $track_data['shipmentDetails']['createdAt'] : '';?></div>
                            </div>

                            <div class="trackfree-dt-ls">
                                <span class="trackfree_details_label"><?php echo __('Customer Name', 'trackfree-woocommerce-tracking');?></span>
                                <div><?php echo isset($track_data['shipmentDetails']['orderId']) && $track_data['shipmentDetails']['orderId'] ? $track_data['shipmentDetails']['orderId'] : '';?></div>
                            </div>

                            <div class="trackfree-dt-ls">
                                <span class="trackfree_details_label"><?php echo __('Customer Email', 'trackfree-woocommerce-tracking');?></span>
                                <div><?php echo isset($track_data['shipmentDetails']['customerEmail']) && $track_data['shipmentDetails']['customerEmail'] ? $track_data['shipmentDetails']['customerEmail'] : '';?></div>
                            </div>

                            <div class="trackfree-dt-ls">
                                <span class="trackfree_details_label"><?php echo __('Customer Phone', 'trackfree-woocommerce-tracking');?> #</span>
                                <div><?php echo isset($track_data['shipmentDetails']['customerPhone']) && $track_data['shipmentDetails']['customerPhone'] ? $track_data['shipmentDetails']['customerPhone'] : '';?></div>
                            </div>

                            <div class="trackfree-dt-ls">
                                <span class="trackfree_details_label"><?php echo __('Notes (Visible only to you)', 'trackfree-woocommerce-tracking');?></span>
                                <div><?php echo isset($track_data['shipmentDetails']['internalNote']) && $track_data['shipmentDetails']['internalNote'] ? $track_data['shipmentDetails']['internalNote'] : '';?></div>
                            </div>

                            <div class="trackfree-dt-ls">
                                <span class="trackfree_details_label"><?php echo __('Customer Feedback', 'trackfree-woocommerce-tracking');?></span>
                                <div><?php echo isset($track_data['shipmentDetails']['comments']) && $track_data['shipmentDetails']['comments'] ? $track_data['shipmentDetails']['comments'] : '';?></div>
                            </div>
                        </div>
                    </div>
                    <div id="tf_cs_ct" style="display: none;">
                        <div>
                            <div class="trackfree-ca-ct">
                                <span class="tfree_carrier_logo"></span>
                                <div class="trackfree-ca-cp">
                                    <?php echo $track_data['courierCaption'];?>
                                </div>
                            </div>
                            <?php if (isset($track_data['carrierContact']['phoneNumber'])) { ?>
                                <div class="trackfree-ca-ct">
                                    <span class="tfree_carrier_phone"></span>
                                    <div class="trackfree-ca-cp">
                                        <a href="tel:<?php echo $track_data['carrierContact']['phoneNumber'];?>" style="text-decoration: none;"><?php echo $track_data['carrierContact']['phoneNumber'];?></a>
                                    </div>
                                </div>
                            <?php } ?>
                            <?php if (isset($track_data['carrierContact']['website'])) { ?>
                                <div class="trackfree-ca-ct">
                                    <span class="tfree_carrier_phone"></span>
                                    <div class="trackfree-ca-cp">
                                        <a href="<?php echo $track_data['carrierContact']['trackUrl'];?>" target="_blank" style="text-decoration: none;"><?php echo $track_data['carrierContact']['website'];?></a>
                                    </div>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                    <div id="tf_nf_ct" style="display: none;">
                        <div style="padding: 32px;">
                            <?php if (sizeof ($track_data['emailNotifications']) > 0) {
                                ?>
                                <div>
                                    <table style="width: 90%;">
                                        <tbody>
                                            <?php foreach ($track_data['emailNotifications'] as $item) { ?>
                                                <tr>
                                                    <td style="width:10%;"><span class="trackfree_status_pointer"></span></td>
                                                    <td style="width: 20%; text-align: center; padding: 10px 0px 10px 0px;">
                                                        <span class="trackfree_status_date"><?php echo $item['createdDate'];?> <?php echo $item['createdTime'];?></span>
                                                    </td>
                                                    <td style="width: 70%; padding: 10px 20px 10px 10px;">
                                                        <span class="trackfree_status_detail">
                                                            <div>
                                                                <?php echo $item['type'];?>
                                                            </div>
                                                            <div class="trackfree-link" style="font-size: 12px;" onclick="window.open('<?php echo trackfree_url();?>/wc_user_connect?key=<?php echo $trackfree_account_api_key;?>&tfs=wp&tfp=tracking&acn=<?php echo $track_data['trackingNum'];?>')"><?php _e('Preview in TrackFree Web App', 'trackfree-woocommerce-tracking');?></div>
                                                        </span>
                                                    </td>
                                                </tr>
                                            <?php } ?>
                                        </tbody>
                                    </table>
                                </div>
                                <?php
                            } else { ?>
                                <div>
                                    <?php _e('No notifications', 'trackfree-woocommerce-tracking');?>
                                </div>
                                <?php
                            }?>
                        </div>
                    </div>
                </div>
                <?php
            }
        }
        wp_die();
    }
}
?>
