<?php
if (!defined( 'ABSPATH'))
    exit;

if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    function trackfree_tracking_page()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            $trackfree_account_api_key = get_option('trackfree_account_api_key');
            $trackfree_account_verify = get_option('trackfree_account_verify');

            if (isset($_POST['_wpnonce']) && wp_verify_nonce($_POST['_wpnonce'], 'TrackFree')) {
                trackfree_tracking_action();
            }
            $appVerifyContent = '';

            if ($trackfree_account_api_key == '') {
                include ('getting-started.php');
            }
            if (($trackfree_account_api_key) && ($trackfree_account_verify == 0)) {
                $appVerifyContent = '<div class="trackfree-error-container">' . __('Your app is not verified. Click verify link and activate your app in your mail. Please refresh this page if you have already verified.', 'trackfree-woocommerce-tracking') . '</div>';
                include ('getting-started.php');
            }

            if (($trackfree_account_verify == 0) && ($trackfree_account_api_key)) {
                trackfree_verification_status();
            }

            if (($trackfree_account_api_key) && ($trackfree_account_verify)) {
                trackfree_tracking_page_action();
            }
        }
    }

    function trackfree_tracking_action()
    {
        $user_id = get_current_user_id();
        if (current_user_can('edit_user', $user_id)) {
            if (isset($_POST['display_options'])) {
                $request_data = array(
                    'cont_width' => sanitize_text_field($_POST['cont_width']),
                    'width_type' => $_POST['width_type'],
                    'pg_bar_color' => sanitize_text_field($_POST['pg_bar_color']),
                    'by_ord_num_email' => isset($_POST['by_ord_num_email']) ? 1 : 0,
                    'by_tk_num' => isset($_POST['by_tk_num']) ? 1 : 0,
                    'show_cr_nm' => isset($_POST['show_cr_nm']) ? 1 : 0,
                    'show_track_num' => isset($_POST['show_track_num']) ? 1 : 0,
                    'show_track_info' => isset($_POST['show_track_info']) ? 1 : 0,
                    'show_map' => isset($_POST['show_map']) ? 1 : 0,
                    'show_rec_prds' => isset($_POST['show_rec_prds']) ? 1 : 0,
                    'show_trackfree_branding' => isset($_POST['show_trackfree_branding']) ? 1 : 0,
                );
                update_option('trackfree_display_options', $request_data);
            }

            if (isset($_POST['internal_link_option'])) {
                $option = isset($_POST['trackfree_internal_email_link']) ? 1 : 0;
                update_option('trackfree_internal_email_link', $option);

                wp_remote_post(trackfree_url() . '/api/wc_tracking_link?key=' . get_option('trackfree_account_api_key'),
                    array(
                        'sslverify' => false,
                        'timeout' => 15,
                        'body' => [
                            'option' => $option,
                            'tracking_url' => trackfree_track_page_url('', false)
                        ]
                    )
                );
            }

            if (isset($_POST['trans_strings'])) {
                $track_page_id = get_option('trackfree_track_page_id');
                $page_info = get_post($track_page_id);
                if (!empty($page_info)) {
                    $tf_page = [
                        'ID' =>  $page_info->ID,
                        'post_title'   => sanitize_text_field($_POST['track_order_status']),
                        'post_name'    => $page_info->post_name,
                        'post_content' => $page_info->post_content,
                        'post_status'  => 'publish',
                        'post_type'    => 'page',
                        'post_author'  => 1,
                    ];
                    wp_update_post($tf_page);
                }

                $request_data = array(
                    'track_order_status' => sanitize_text_field($_POST['track_order_status']),
                    'order_number' => sanitize_text_field($_POST['order_number']),
                    'tracking_number' => sanitize_text_field($_POST['tracking_number']),
                    'email' => sanitize_text_field($_POST['email']),
                    'track' => sanitize_text_field($_POST['track']),
                    'order' => sanitize_text_field($_POST['order']),
                    'shipment' => sanitize_text_field($_POST['shipment']),
                    'status' => sanitize_text_field($_POST['status']),
                    'carrier' => sanitize_text_field($_POST['carrier']),
                    'ordered' => sanitize_text_field($_POST['ordered']),
                    'order_ready' => sanitize_text_field($_POST['order_ready']),
                    'in_transit' => sanitize_text_field($_POST['in_transit']),
                    'out_for_delivery' => sanitize_text_field($_POST['out_for_delivery']),
                    'delivered' => sanitize_text_field($_POST['delivered']),
                    'may_like' => sanitize_text_field($_POST['may_like']),
                    'order_not_found' => sanitize_text_field($_POST['order_not_found']),
                );
                update_option('trackfree_trans_strings', $request_data);
            }

            if (isset($_POST['date_time_formats'])) {
                $request_data = array(
                    'date_format' => $_POST['date_format'],
                    'time_format' => $_POST['time_format']
                );

                update_option('trackfree_date_time_formats', $request_data);
            }

            if (isset($_POST['manual_translations'])) {
                $request_data = array(
                    'original_text' => $_POST['original_text'],
                    'replace_text' => $_POST['replace_text'],
                );

                update_option('trackfree_translate_strings', $request_data);
            }

            if (isset($_POST['additional_texts'])) {
                $request_data = array(
                    'text_above' => sanitize_text_field($_POST['text_above']),
                    'text_below' => sanitize_text_field($_POST['text_below']),
                );

                update_option('trackfree_additional_texts', $request_data);
            }

            if (isset($_POST['custom_css_and_html'])) {
                $request_data = array(
                    'custom_css' => $_POST['custom_css'],
                    'custom_html_above' => stripslashes($_POST['custom_html_above']),
                    'custom_html_below' => stripslashes($_POST['custom_html_below']),
                );

                update_option('trackfree_custom_css_and_html', $request_data);
            }
        }
    }

    function trackfree_tracking_page_action()
    {
        $nonce = wp_create_nonce( 'TrackFree' );

        $cont_width = 1200;
        $width_type = 'pixel';
        $pg_bar_color = '#017501';
        $by_ord_num_email = 1;
        $by_tk_num = 1;
        $show_cr_nm = 1;
        $show_track_num = 1;
        $show_track_info = 1;
        $show_map = 1;
        $show_rec_prds = 1;
        $show_trackfree_branding = 1;

        $track_order_status = "Track Order Status";
        $order_number = 'Order Number';
        $tracking_number = 'Tracking Number';
        $email = 'Email';
        $track = 'Track';
        $order = 'Order';
        $shipment = 'Shipment';
        $status = 'Status';
        $carrier = 'Carrier';
        $ordered = 'Ordered';
        $order_ready = 'Order Ready';
        $in_transit = 'In Transit';
        $out_for_delivery = 'Out for Delivery';
        $delivered = 'Delivered';
        $may_like = 'You may also like...';
        $order_not_found = 'Order Not Found';

        $date_format = 1;
        $time_format = 1;

        $text_above = '';
        $text_below = '';

        $custom_css = '';
        $custom_html_above= '';
        $custom_html_below = '';

        $tf_dis_opt = get_option('trackfree_display_options');
        if ($tf_dis_opt) {
            $cont_width = isset($tf_dis_opt['cont_width']) ? $tf_dis_opt['cont_width'] : 1200;
            $width_type = isset($tf_dis_opt['width_type']) ? $tf_dis_opt['width_type'] : 'pixel';
            $pg_bar_color = isset($tf_dis_opt['pg_bar_color']) ? $tf_dis_opt['pg_bar_color'] : '#017501';
            $by_ord_num_email = isset($tf_dis_opt['by_ord_num_email']) ? $tf_dis_opt['by_ord_num_email'] : 1;
            $by_tk_num = isset($tf_dis_opt['by_tk_num']) ? $tf_dis_opt['by_tk_num'] : 1;
            $show_cr_nm = isset($tf_dis_opt['show_cr_nm']) ? $tf_dis_opt['show_cr_nm'] : 1;
            $show_track_num = isset($tf_dis_opt['show_track_num']) ? $tf_dis_opt['show_track_num'] : 1;
            $show_track_info = isset($tf_dis_opt['show_track_info']) ? $tf_dis_opt['show_track_info'] : 1;
            $show_map = isset($tf_dis_opt['show_map']) ? $tf_dis_opt['show_map'] : 1;
            $show_rec_prds = isset($tf_dis_opt['show_rec_prds']) ? $tf_dis_opt['show_rec_prds'] : 1;
            $show_trackfree_branding = isset($tf_dis_opt['show_trackfree_branding']) ? $tf_dis_opt['show_trackfree_branding'] : 1;
        }

        $tf_tns_str = get_option('trackfree_trans_strings');
        if ($tf_tns_str) {
            $track_order_status = isset($tf_tns_str['track_order_status']) ? $tf_tns_str['track_order_status'] : 'Track Order Status';
            $order_number = isset($tf_tns_str['order_number']) ? $tf_tns_str['order_number'] : 'Order Number';
            $tracking_number = isset($tf_tns_str['tracking_number']) ? $tf_tns_str['tracking_number'] : 'Tracking Number';
            $email = isset($tf_tns_str['email']) ? $tf_tns_str['email'] : 'Email';
            $track = isset($tf_tns_str['track']) ? $tf_tns_str['track'] : 'Track';
            $order = isset($tf_tns_str['order']) ? $tf_tns_str['order'] : 'Order';
            $shipment = isset($tf_tns_str['shipment']) ? $tf_tns_str['shipment'] : 'Shipment';
            $status = isset($tf_tns_str['status']) ? $tf_tns_str['status'] : 'Status';
            $carrier = isset($tf_tns_str['carrier']) ? $tf_tns_str['carrier'] : 'Carrier';
            $ordered = isset($tf_tns_str['ordered']) ? $tf_tns_str['ordered'] : 'Ordered';
            $order_ready = isset($tf_tns_str['order_ready']) ? $tf_tns_str['order_ready'] : 'Order Ready';
            $in_transit = isset($tf_tns_str['in_transit']) ? $tf_tns_str['in_transit'] : 'In Transit';
            $out_for_delivery = isset($tf_tns_str['out_for_delivery']) ? $tf_tns_str['out_for_delivery'] : 'Out for Delivery';
            $delivered = isset($tf_tns_str['delivered']) ? $tf_tns_str['delivered'] : 'Delivered';
            $may_like = isset($tf_tns_str['may_like']) ? $tf_tns_str['may_like'] : 'You may also like...';
            $order_not_found = isset($tf_tns_str['order_not_found']) ? $tf_tns_str['order_not_found'] : 'Order Not Found';
        }

        $tf_dtm_fms = get_option('trackfree_date_time_formats');

        if ($tf_dtm_fms) {
            $date_format = isset($tf_dtm_fms['date_format']) ? $tf_dtm_fms['date_format'] : 1;
            $time_format = isset($tf_dtm_fms['time_format']) ? $tf_dtm_fms['time_format'] : 1;
        }

        $total_trans = 0;
        $tf_tns_stn = get_option('trackfree_translate_strings');
        if ($tf_tns_stn) {
            $total_trans = sizeof ($tf_tns_stn['original_text']);
        }

        $tf_add_txt = get_option('trackfree_additional_texts');
        if ($tf_add_txt) {
            $text_above = isset($tf_add_txt['text_above']) ? $tf_add_txt['text_above'] : '';
            $text_below = isset($tf_add_txt['text_below']) ? $tf_add_txt['text_below'] : '';
        }

        $tf_css_htm = get_option('trackfree_custom_css_and_html');
        if ($tf_css_htm) {
            $custom_css = isset($tf_css_htm['custom_css']) ? $tf_css_htm['custom_css'] : '';
            $custom_html_above= isset($tf_css_htm['custom_html_above']) ? $tf_css_htm['custom_html_above'] : '';
            $custom_html_below = isset($tf_css_htm['custom_html_below']) ? $tf_css_htm['custom_html_below'] : '';
        }
        ?>
        <div class="wrap">
            <div style="display: flex; align-items: center;">
                <h1 class="wp-heading-inline"><?php _e('Tracking Page', 'trackfree-woocommerce-tracking');?></h1>
            </div>
            <p class="nav-tab-wrapper"></p>
            <div style="clear:both;"></div>
            <div class="trackfree-main-box">
                <div class="trackfree-row">
                    <div class="trackfree-col-2">
                        <h2><?php _e('Display options', 'trackfree-woocommerce-tracking');?></h2>
                        <div class="trackfree-description">
                            <?php _e('You can hide or display tracking page components by preference.', 'trackfree-woocommerce-tracking');?>
                        </div>
                    </div>
                    <div class="trackfree-col-9">
                        <div class="postbox">
                            <div class="inside">
                                <div class="main">
                                    <div class="trackfree-pv-bn">
                                        <button style="float: right;" onclick="window.open('<?php  echo trackfree_track_page_url('', true)?>')" type="button" class="button"><?php echo __('Preview', 'trackfree-woocommerce-tracking'); ?></button>
                                        <div style="clear: both;">&nbsp;</div>
                                    </div>
                                    <form method="post" action="<?php echo admin_url('admin.php?page=trackfree-tracking-page');?>">
                                        <table class="form-table">
                                            <tbody>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e("Theme container width", 'trackfree-woocommerce-tracking');?>
                                                    </th>
                                                    <td>
                                                        <div style="display: flex;">
                                                            <div>
                                                                <input type="text" name="cont_width" id="cont_width" value="<?php echo $cont_width;?>" />
                                                            </div>
                                                            <div style="display: flex; margin-left: 16px;">
                                                                <div class="trackfree-toggle-btn">
                                                                    <input type="radio" id="tf_width_px" name="width_type" value="pixel" <?php if ($width_type=='pixel') { ?>checked <?php } ?> />
                                                                    <label for="tf_width_px">px</label>
                                                                </div>
                                                                <div class="trackfree-toggle-btn">
                                                                    <input type="radio" id="tf_width_pc" name="width_type" value="percentage" <?php if ($width_type=='percentage') { ?>checked <?php } ?> />
                                                                    <label for="tf_width_pc">%</label>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e("Progress bar color", 'trackfree-woocommerce-tracking');?>
                                                    </th>
                                                    <td>
                                                        <input type="text" name="pg_bar_color" id="pg_bar_color" value="<?php echo $pg_bar_color;?>" class="trackfree-color-field" data-default-color="<?php echo $pg_bar_color;?>" />
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e("Look up options", 'trackfree-woocommerce-tracking');?>
                                                    </th>
                                                    <td>
                                                        <input type="checkbox" id="by_ord_num_email" name="by_ord_num_email" value="1" <?php if ($by_ord_num_email==1) { ?>checked <?php } ?> />
                                                        <label for="by_ord_num_email">
                                                            <?php _e('By order number and email', 'trackfree-woocommerce-tracking');?>
                                                        </label>
                                                        <input type="checkbox" id="by_tk_num" name="by_tk_num" value="1" <?php if ($by_tk_num==1) { ?>checked
                                                        <?php } ?> style="margin-left: 16px;" />
                                                        <label for="by_tk_num">
                                                            <?php _e('By tracking number', 'trackfree-woocommerce-tracking');?>
                                                        </label>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e("Carrier details", 'trackfree-woocommerce-tracking');?>
                                                    </th>
                                                    <td>
                                                        <input type="checkbox" id="show_cr_nm" name="show_cr_nm" value="1" <?php if ($show_cr_nm==1) { ?>checked <?php } ?> />
                                                        <label for="show_cr_nm">
                                                            <?php _e("Show the carrier's name and logo on your tracking page", 'trackfree-woocommerce-tracking');?>
                                                        </label>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e("Tracking number", 'trackfree-woocommerce-tracking');?>
                                                    </th>
                                                    <td>
                                                        <input type="checkbox" id="show_track_num" name="show_track_num" value="1" <?php if ($show_track_num==1) { ?>checked<?php } ?> />
                                                        <label for="show_track_num">
                                                            <?php _e('Show tracking number on your tracking page', 'trackfree-woocommerce-tracking');?>
                                                        </label>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e("Tracking detailed info", 'trackfree-woocommerce-tracking');?>
                                                    </th>
                                                    <td>
                                                        <input type="checkbox" id="show_track_info" name="show_track_info" value="1" <?php if ($show_track_info==1) { ?>checked<?php } ?> />
                                                        <label for="show_track_info">
                                                            <?php _e('Show tracking details on your tracking page', 'trackfree-woocommerce-tracking');?>
                                                        </label>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e("Map coordinates", 'trackfree-woocommerce-tracking');?>
                                                    </th>
                                                    <td>
                                                        <input type="checkbox" id="show_map" name="show_map" value="1" <?php if ($show_map==1 ) { ?>checked
                                                        <?php } ?> />
                                                        <label for="show_map">
                                                            <?php _e('Show map on your tracking page when the address is recognized correctly', 'trackfree-woocommerce-tracking');?>
                                                        </label>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e("Recommended products", 'trackfree-woocommerce-tracking');?>
                                                    </th>
                                                    <td>
                                                        <input type="checkbox" id="show_rec_prds" name="show_rec_prds" value="1" <?php if ($show_rec_prds==1 ) { ?>checked<?php } ?> />
                                                        <label for="show_rec_prds">
                                                            <?php _e('Recommended products will be shown to customers based on their order items', 'trackfree-woocommerce-tracking');?>
                                                        </label>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e("TrackFree branding", 'trackfree-woocommerce-tracking');?>
                                                    </th>
                                                    <td>
                                                        <input type="checkbox" id="show_trackfree_branding" name="show_trackfree_branding" value="1" <?php if ($show_trackfree_branding==1 ) { ?>checked<?php } ?> />
                                                        <label for="show_trackfree_branding">
                                                            <?php _e('Show powered by TrackFree branding on your tracking page', 'trackfree-woocommerce-tracking');?>
                                                        </label>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                        <input type="hidden" value="<?php echo $nonce; ?>" name="_wpnonce" />
                                        <input type="hidden" value="true" name="display_options" />
                                        <div>
                                            <?php submit_button(); ?>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div style="clear: both;">&nbsp;</div>
            </div>
            <div class="trackfree-main-box">
                <div class="trackfree-row">
                    <div class="trackfree-col-2">
                        <h2><?php _e('Translation strings', 'trackfree-woocommerce-tracking');?></h2>
                        <div class="trackfree-description">
                            <?php _e('You can modify these strings to match the language of your customers.', 'trackfree-woocommerce-tracking');?>
                        </div>
                    </div>
                    <div class="trackfree-col-9">
                        <div class="postbox">
                            <div class="inside">
                                <div class="main">
                                    <form method="post" action="<?php echo admin_url('admin.php?page=trackfree-tracking-page');?>">
                                        <table class="form-table">
                                            <tbody>
                                                <tr class="trackfree-ln-sp">
                                                    <th scope="row">
                                                        <h3><?php _e('Header', 'trackfree-woocommerce-tracking'); ?></h3>
                                                    </th>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e('Page title', 'trackfree-woocommerce-tracking'); ?>
                                                    </th>
                                                    <td>
                                                        <input type="text" name="track_order_status" id="track_order_status" value="<?php echo $track_order_status;?>" class="trackfree-regular-text" placeholder="Track Order Status" />
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e('Tab', 'trackfree-woocommerce-tracking'); ?> 1
                                                    </th>
                                                    <td>
                                                        <input type="text" name="order_number" id="order_number" value="<?php echo $order_number;?>" class="trackfree-regular-text" placeholder="Order Number" />
                                                        <p class="trackfree-sp-mn"></p>
                                                        <input type="text" name="email" id="email" value="<?php echo $email;?>" class="trackfree-regular-text" placeholder="Email" />
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e('Tab', 'trackfree-woocommerce-tracking'); ?> 2
                                                    </th>
                                                    <td>
                                                        <input type="text" name="tracking_number" id="tracking_number" value="<?php echo $tracking_number;?>" class="trackfree-regular-text" placeholder="Tracking Number" />
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e('Primary CTA', 'trackfree-woocommerce-tracking'); ?>
                                                    </th>
                                                    <td>
                                                        <input type="text" name="track" id="track" value="<?php echo $track;?>" class="trackfree-regular-text" placeholder="Track" />
                                                    </td>
                                                </tr>
                                                <tr class="trackfree-ln-sp">
                                                    <th scope="row">
                                                        <h3><?php _e('Body & Footer', 'trackfree-woocommerce-tracking'); ?></h3>
                                                    </th>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e('Body header', 'trackfree-woocommerce-tracking'); ?>
                                                    </th>
                                                    <td>
                                                        <input type="text" name="order" id="order" value="<?php echo $order;?>" class="trackfree-regular-text" placeholder="Order" />
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e('Shipment info', 'trackfree-woocommerce-tracking'); ?>
                                                    </th>
                                                    <td>
                                                        <input type="text" name="shipment" id="shipment" value="<?php echo $shipment;?>" class="trackfree-regular-text" placeholder="Shipment" />
                                                        <p class="trackfree-sp-mn"></p>
                                                        <input type="text" name="status" id="status" value="<?php echo $status;?>" class="trackfree-regular-text" placeholder="Status" />
                                                        <p class="trackfree-sp-mn"></p>
                                                        <input type="text" name="carrier" id="carrier" value="<?php echo $carrier;?>" class="trackfree-regular-text" placeholder="Carrier" />
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e('Shipment statuses', 'trackfree-woocommerce-tracking'); ?>
                                                    </th>
                                                    <td>
                                                        <input type="text" name="ordered" id="ordered" value="<?php echo $ordered;?>" class="trackfree-regular-text" placeholder="Ordered" />
                                                        <p class="trackfree-sp-mn"></p>
                                                        <input type="text" name="order_ready" id="order_ready" value="<?php echo $order_ready;?>" class="trackfree-regular-text" placeholder="Order Ready" />
                                                        <p class="trackfree-sp-mn"></p>
                                                        <input type="text" name="in_transit" id="in_transit" value="<?php echo $in_transit;?>" class="trackfree-regular-text" placeholder="In Transit" />
                                                        <p class="trackfree-sp-mn"></p>
                                                        <input type="text" name="out_for_delivery" id="out_for_delivery" value="<?php echo $out_for_delivery;?>" class="trackfree-regular-text" placeholder="Out for Delivery" />
                                                        <p class="trackfree-sp-mn"></p>
                                                        <input type="text" name="delivered" id="delivered" value="<?php echo $delivered;?>" class="trackfree-regular-text" placeholder="Delivered" />
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e('Recommended products', 'trackfree-woocommerce-tracking'); ?>
                                                    </th>
                                                    <td>
                                                        <input type="text" name="may_like" id="may_like" value="<?php echo $may_like;?>" class="trackfree-regular-text" placeholder="You may also like..." />
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th scope="row">
                                                        <?php _e('Order Not Found', 'trackfree-woocommerce-tracking'); ?>
                                                    </th>
                                                    <td>
                                                        <input type="text" name="order_not_found" id="order_not_found" value="<?php echo $order_not_found;?>" class="trackfree-regular-text" placeholder="Order Not Found" />
                                                    </td>
                                                </tr>

                                            </tbody>
                                        </table>
                                        <input type="hidden" value="<?php echo $nonce; ?>" name="_wpnonce" />
                                        <input type="hidden" value="true" name="trans_strings" />
                                        <div>
                                            <?php submit_button(); ?>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div style="clear: both;">&nbsp;</div>
            </div>
            <div class="trackfree-main-box">
                <div class="trackfree-row">
                    <div class="trackfree-col-2">
                        <h2><?php _e('Date and time format', 'trackfree-woocommerce-tracking');?></h2>
                    </div>
                    <div class="trackfree-col-9">
                        <div class="postbox">
                            <div class="inside">
                                <div class="main">
                                    <form method="post" action="<?php echo admin_url('admin.php?page=trackfree-tracking-page');?>">
                                        <table class="form-table">
                                            <tbody>
                                                <tr>
                                                    <td>
                                                        <p><?php _e("Date format", 'trackfree-woocommerce-tracking');?></p>
                                                        <select name="date_format" id="date_format" class="form-field-wide">
                                                            <option value="1" <?php if ($date_format==1) { ?>selected<?php } ?>><?php echo date('M d, Y', strtotime('now'));?></option>
                                                            <option value="2" <?php if ($date_format==2) { ?>selected<?php } ?>><?php echo date('M d', strtotime('now'));?></option>
                                                            <option value="3" <?php if ($date_format==3) { ?>selected<?php } ?>><?php echo date('M jS, Y', strtotime('now'));?></option>
                                                            <option value="4" <?php if ($date_format==4) { ?>selected<?php } ?>><?php echo date('d M Y', strtotime('now'));?></option>
                                                            <option value="5" <?php if ($date_format==5) { ?>selected<?php } ?>><?php echo date('d-M-Y', strtotime('now'));?></option>
                                                            <option value="6" <?php if ($date_format==6) { ?>selected<?php } ?>><?php echo date('m/d/Y', strtotime('now')) . ' (m/d/yyyy)';?></option>
                                                            <option value="7" <?php if ($date_format==7) { ?>selected<?php } ?>><?php echo date('d/m/Y', strtotime('now')) . ' (d/m/yyyy)';?></option>
                                                        </select>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td>
                                                        <p><?php _e("Time format", 'trackfree-woocommerce-tracking');?></p>
                                                        <select name="time_format" id="time_format" class="form-field-wide">
                                                            <option value="1" <?php if ($time_format==1) { ?>selected <?php } ?>><?php echo date('h:i a', strtotime('now'));?>
                                                            </option><option value="2" <?php if ($time_format==2) { ?>selected<?php } ?>><?php _e("24-hour time", 'trackfree-woocommerce-tracking');?></option>
                                                        </select>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                        <input type="hidden" value="<?php echo $nonce; ?>" name="_wpnonce" />
                                        <input type="hidden" value="true" name="date_time_formats" />
                                        <div>
                                            <?php submit_button(); ?>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div style="clear: both;">&nbsp;</div>
            </div>

            <div class="trackfree-main-box">
                <div class="trackfree-row">
                    <div class="trackfree-col-2">
                        <h2><?php _e('Manually translate tracking detailed info', 'trackfree-woocommerce-tracking');?></h2>
                        <div class="trackfree-description">
                            <?php _e('You can manually translate the tracking details here.', 'trackfree-woocommerce-tracking');?>
                            <p>
                                <?php _e("Note: This feature distinguishes strings based on spaces; please make sure you include the comma and period when you translate.", 'trackfree-woocommerce-tracking');?>
                            </p>
                        </div>
                    </div>
                    <div class="trackfree-col-9">
                        <div class="postbox">
                            <div class="inside">
                                <div class="main">
                                    <form method="post" action="<?php echo admin_url('admin.php?page=trackfree-tracking-page');?>">
                                        <table class="form-table">
                                            <tbody class="trackfree_tns_sec">
                                                <?php
                                                if ($total_trans > 0) {
                                                    $i = 1;
                                                    foreach ($tf_tns_stn['original_text'] as $key => $ot) {
                                                        if ($ot || $i == 1) { ?>
                                                            <tr class="trackfree_tns_cnt">
                                                                <td>
                                                                    <?php if ($i == 1) { ?>
                                                                        <p><?php _e("Tracking info (before translation)", 'trackfree-woocommerce-tracking');?></p>
                                                                    <?php } ?>
                                                                    <input type="text" name="original_text[]" placeholder="e.g. China" value="<?php echo $ot;?>" class="trackfree-regular-text" />
                                                                </td>
                                                                <td>
                                                                    <?php if ($i == 1) { ?>
                                                                        <p><?php _e("Tracking info (after translation)", 'trackfree-woocommerce-tracking');?></p>
                                                                    <?php } ?>
                                                                    <input type="text" name="replace_text[]" placeholder="Sorting Center" value="<?php echo $tf_tns_stn['replace_text'][$key];?>" class="trackfree-regular-text" />
                                                                    <?php if ($i != 1) {?>
                                                                        <td>
                                                                            <button type="button" class="button trackfree_remove_trans"><span class="trackfree_rm_ic"></span></button>
                                                                        </td>
                                                                    <?php } ?>
                                                                </td>
                                                            </tr>
                                                            <?php
                                                        }
                                                        $i++;
                                                    }
                                                } else { ?>
                                                    <tr class="trackfree_tns_cnt">
                                                        <td>
                                                            <p><?php _e("Tracking info (before translation)", 'trackfree-woocommerce-tracking');?></p>
                                                            <input type="text" name="original_text[]" placeholder="e.g. China" value="" class="trackfree-regular-text" />
                                                        </td>
                                                        <td>
                                                            <p><?php _e("Tracking info (after translation)", 'trackfree-woocommerce-tracking');?></p>
                                                            <input type="text" name="replace_text[]" placeholder="Sorting Center" value="" class="trackfree-regular-text" />
                                                        </td>
                                                    </tr>
                                                <?php } ?>
                                            </tbody>
                                        </table>
                                        <input type="hidden" value="<?php echo $nonce; ?>" name="_wpnonce" />
                                        <input type="hidden" value="true" name="manual_translations" />
                                        <div class="trackfree-mt-bn">
                                            <button type="button" class="button trackfree_add_trans"><?php _e("Add another", 'trackfree-woocommerce-tracking');?></button>
                                        </div>
                                        <div>
                                            <?php submit_button(); ?>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div style="clear: both;">&nbsp;</div>
            </div>

            <div class="trackfree-main-box">
                <div class="trackfree-row">
                    <div class="trackfree-col-2">
                        <h2><?php _e('Additional text setting', 'trackfree-woocommerce-tracking');?></h2>
                        <div class="trackfree-description">
                            <?php _e('Additional content can be added above and below the order lookup section using these fields.', 'trackfree-woocommerce-tracking');?>
                        </div>
                    </div>
                    <div class="trackfree-col-9">
                        <div class="postbox">
                            <div class="inside">
                                <div class="main">
                                    <form method="post" action="<?php echo admin_url('admin.php?page=trackfree-tracking-page');?>">
                                        <table class="form-table">
                                            <tbody>
                                                <tr>
                                                    <td>
                                                        <p><?php _e('Text above', 'trackfree-woocommerce-tracking');?></p>
                                                        <textarea id="text_above" name="text_above" rows="4" style="width: 80%"><?php echo $text_above;?></textarea>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td>
                                                        <p><?php _e('Text below', 'trackfree-woocommerce-tracking');?></p>
                                                        <textarea id="text_below" name="text_below" rows="4" style="width: 80%"><?php echo $text_below;?></textarea>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                        <input type="hidden" value="<?php echo $nonce; ?>" name="_wpnonce" />
                                        <input type="hidden" value="true" name="additional_texts" />
                                        <div>
                                            <?php submit_button(); ?>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div style="clear: both;">&nbsp;</div>
            </div>

            <div class="trackfree-main-box">
                <div class="trackfree-row">
                    <div class="trackfree-col-2">
                        <h2><?php _e('Custom CSS and HTML', 'trackfree-woocommerce-tracking');?></h2>
                        <div class="trackfree-description">
                            <?php _e('You can customize the tracking page CSS and HTML according to your preferences.', 'trackfree-woocommerce-tracking');?>
                        </div>
                    </div>
                    <div class="trackfree-col-9">
                        <div class="postbox">
                            <div class="inside">
                                <div class="trackfree-pv-bn">
                                    <button onclick="window.open('<?php  echo trackfree_track_page_url('', true)?>')" type="button" class="button"><?php echo __('Preview', 'trackfree-woocommerce-tracking'); ?></button>
                                    <p>
                                        <?php echo __('Be sure to save your changes before previewing.', 'trackfree-woocommerce-tracking'); ?>
                                    </p>
                                </div>
                                <div class="main">
                                    <form method="post" action="<?php echo admin_url('admin.php?page=trackfree-tracking-page');?>">
                                        <table class="form-table">
                                            <tbody>
                                                <tr>
                                                    <td>
                                                        <p><b>CSS</b></p>
                                                        <textarea id="custom_css" name="custom_css"><?php echo $custom_css ?></textarea>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td>
                                                        <p><b><?php _e('HTML top of the page', 'trackfree-woocommerce-tracking');?></b></p>
                                                        <textarea id="custom_html_above" name="custom_html_above"><?php echo stripslashes($custom_html_above) ?></textarea>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <td>
                                                        <p><b><?php _e('HTML bottom of the page', 'trackfree-woocommerce-tracking');?></b></p>
                                                        <textarea id="custom_html_below" name="custom_html_below"><?php echo stripslashes($custom_html_below); ?></textarea>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                        <input type="hidden" value="<?php echo $nonce; ?>" name="_wpnonce" />
                                        <input type="hidden" value="true" name="custom_css_and_html" />
                                        <div>
                                            <?php submit_button(); ?>
                                        </div>
                                    </form>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div style="clear: both;">&nbsp;</div>
            </div>
            <?php if (get_option('trackfree_hide_track_page_info') == 1) { ?>
                <div class="trackfree-main-box">
                    <div class="trackfree-row">
                        <div class="trackfree-col-2">
                            <h2><?php echo __('Add tracking page to your storefront', 'trackfree-woocommerce-tracking'); ?></h2>
                        </div>
                        <div class="trackfree-col-9">
                            <div class="postbox">
                                <div class="inside">
                                    <div class="main">
                                        <p>
                                            <?php echo sprintf(esc_html__('Your branded tracking page is ready, the URL is %1$s, add it to your store menus so your customers can track orders there.', 'trackfree-woocommerce-tracking'), '<a href="' . trackfree_track_page_url() . '" target="_blank">' . trackfree_track_page_url() . '</a>' ) ?>
                                        </p>
                                        <p>
                                            <?php echo sprintf(esc_html__('Don’t know how to do this? Please follow %1$sthis instruction%2$s.', 'trackfree-woocommerce-tracking')
                                            , '<a href="https://trackfreehelp.freshdesk.com/support/solutions/articles/65000181291" target="_blank">', '</a>') ?>
                                        </p>
                                        <div style="margin: 16px 0">
                                            <button onclick="window.open('<?php  echo trackfree_track_page_url('', true)?>')" type="button" class="button button-primary"><?php echo __('Preview tracking page', 'trackfree-woocommerce-tracking'); ?></button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div style="clear: both;">&nbsp;</div>
                </div>
            <?php } ?>
        </div>
        <?php
    }
}
?>
