<?php
function tf_wc_order_summary($order_id) {
    $user_id = get_current_user_id();
    if (current_user_can('edit_user', $user_id)) {
        $trackfree_account_api_key = get_option('trackfree_account_api_key');
        $trackfree_account_verify  = get_option('trackfree_account_verify');

        if (($trackfree_account_api_key) && ($trackfree_account_verify == 1)) {
            $order = wc_get_order($order_id);
            $order_data = $order->get_data();

            $first_name = $order_data['shipping']['first_name'] ? $order_data['shipping']['first_name'] : $order_data['billing']['first_name'];
            $last_name = $order_data['shipping']['last_name'] ? $order_data['shipping']['last_name'] : $order_data['billing']['last_name'];

            //Refund
            $refund_amount = 0;
            $order_refunds = $order->get_refunds();
            if ($order_refunds) {
                foreach ($order_refunds as $refund) {
                    $refund_amount += $refund->amount;
                }
            }

            $order_items  = array();

            foreach ($order->get_items() as $item_key => $item_values) {
                $item_data = $item_values->get_data();
                $product_data = wc_get_product($item_data['product_id']);

                if (!empty($product_data)) {
                    $product_attribute_name = '';
                    $variant_image_url = '';
                    if ($item_data['variation_id']) {
                        $product = new WC_Product_Variable($item_data['product_id']);
                        $variations = $product->get_available_variations();
                        foreach ($variations as $variation) {
                            if ($variation['variation_id'] == $item_data['variation_id']) {
                                $variant_image_url = $variation['image']['url'];
                                if ($variation['attributes']) {
                                    foreach ($variation['attributes'] as $attribute_name => $attribute_val) {
                                        $product_attribute_name .=  '&' . $attribute_name . '=' . $attribute_val;
                                    }
                                }
                            }
                        }
                    }

                    $order_items[]  = array(
                        'product_id' => $item_data['product_id'],
                        'variation_id' => $item_data['variation_id'],
                        'name' => $item_data['name'],
                        'price' => wc_format_decimal($item_data['subtotal'] / $item_data['quantity'], 2),
                        'sku' => $product_data->get_sku(),
                        'quantity' => $item_data['quantity'],
                        'slug' => $product_data->get_slug() . $product_attribute_name,
                        'line_total' => wc_format_decimal($item_data['subtotal'], 2),
                        'image' => $variant_image_url ? $variant_image_url : get_the_post_thumbnail_url($product_data->get_id(), 'full')
                    );
                }
            }

            $shipping_address = array(
                'shipping_first_name' => $order_data['shipping']['first_name'],
                'shipping_last_name' => $order_data['shipping']['last_name'],
                'shipping_company' => $order_data['shipping']['company'],
                'shipping_address_1' => $order_data['shipping']['address_1'],
                'shipping_address_2' => $order_data['shipping']['address_2'],
                'shipping_city' => $order_data['shipping']['city'],
                'shipping_state' => $order_data['shipping']['state'],
                'shipping_postcode' => $order_data['shipping']['postcode'],
                'shipping_country' => $order_data['shipping']['country']
            );

            //Order fee
            $order_fee = array();
            foreach ($order->get_fees() as $fee_id => $fee) {
                if ($fee['name']) {
                    $order_fee[] = array(
                        'name' => $fee['name'],
                        'total' => $fee['total']
                    );
                }
            }

            $coupon_details = array();
            $order_coupon_items = $order->get_items('coupon');
            foreach( $order_coupon_items as $item_id => $item ) {
                $coupon_data = $item->get_data();
                $coupon_details[] = array(
                    'coupon_code' => $coupon_data['code'],
                    'coupon_amount' => $coupon_data['discount']
                );
            }

            $order_details = array(
                'key' => $trackfree_account_api_key,
                'order_id' => $order_data['id'],
                'order_created_at' => $order_data['date_created'] ? $order_data['date_created']->date('Y-m-d H:i:s') : '',
                'order_status' => $order_data['status'],
                'order_currency' => $order_data['currency'],
                'order_total' => wc_format_decimal($order_data['total'], 2),
                'payment_method' => $order_data['payment_method_title'],
                'transaction_id' => $order_data['transaction_id'] ? $order_data['transaction_id'] : '',
                'customer_name' => $last_name ? $first_name . ' ' . $last_name : $first_name,
                'customer_email' => $order_data['billing']['email'],
                'customer_phone' => $order_data['billing']['phone'],
                'customer_country' => $order_data['billing']['country'],
                'order_items' => $order_items,
                'site_url' => home_url(),
                'shipping_address' => $shipping_address,
                'shipping_method' => $order->get_shipping_method(),
                'sub_total' => wc_format_decimal($order->get_subtotal(), 2),
                'total_discount' => wc_format_decimal($order->get_total_discount(), 2),
                'total_shipping' => wc_format_decimal($order->get_total_shipping(), 2),
                'total_tax' =>  wc_format_decimal($order->get_total_tax(), 2),
                'refund_total' => wc_format_decimal($refund_amount, 2),
                'shipment_details' => get_post_meta($order_id, '_trackfree_shipment_details', true),
                'customer_note' => $order->get_customer_note(),
                'order_fee' => $order_fee,
                'coupon_details' => $coupon_details
            );

            wp_remote_post(trackfree_url() . '/api/wc_order_summary', array(
                'sslverify' => false,
                'timeout' => 15,
                'body' => $order_details
            ));
        }
    }
}

add_action('save_post', 'tf_wc_admin_order');

function tf_wc_admin_order() {
    if (!current_user_can('manage_options')) {
        return false;
    }

    if (!is_admin()) {
        return false;
    }

    if ((isset($_REQUEST['post_type'])) && ($_REQUEST['post_type'] != 'shop_order')) {
        return false;
    }

    if ((isset($_REQUEST['post_ID'])) && ($_REQUEST['post_ID'] != '')) {
        $order_id = $_REQUEST['post_ID'];
        tf_wc_order_summary($order_id);
    }
}

add_action('woocommerce_checkout_order_processed', 'tf_wc_checkout_processed_order', 1, 1);

function tf_wc_checkout_processed_order($order_id) {
    tf_wc_order_summary($order_id);
}
?>
